@@ -87,16 +87,20 @@ gboolean chum_get_duetto(){
 
 
 //FALSE means advanced_game
-static gboolean chum_easy_game = TRUE;
 gboolean chum_is_easy_game(){
-  return chum_easy_game;
+	TangleProperties* properties;
+	properties = TANGLE_PROPERTIES(jammo_get_object_by_id("global_game_properties"));
+	return tangle_properties_get_boolean(properties, "easy_game_level");
 }
 
 void chum_set_easy_game(gboolean b){
+	TangleProperties* properties;
+	properties = TANGLE_PROPERTIES(jammo_get_object_by_id("global_game_properties"));
+	tangle_properties_set_boolean(properties, "easy_game_level",b);
+
 	gchar* message = g_strdup_printf("Game level set to %s", b ? "easy":"advanced");
 	cem_add_to_log(message,J_LOG_DEBUG);
 	g_free(message);
-	chum_easy_game=b;
 }
 
 
@@ -148,25 +152,28 @@ gboolean jammo_easy_changed(TangleActor* actor, gpointer data){
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
-	TangleButton* tanglebutton = TANGLE_BUTTON(jammo_get_actor_by_id("main-menu-skill-level-button"));
-
 	ClutterActor* view = jammo_get_actor_by_id("main-menu-view");
 
 		if (strcmp(name,"cancel")==0) {
-			tangle_button_set_selected(tanglebutton,!tangle_button_get_selected(tanglebutton));
 			main_menu_go_back_to_main_menu(NULL,NULL);
 			return TRUE; //Do not do any loading
 		}
 
 	if (strcmp(name,"easy")==0)
 		{
-		tangle_button_set_selected(tanglebutton,FALSE);
+		if (chum_is_easy_game()){
+			main_menu_go_back_to_main_menu(NULL,NULL);
+			return TRUE; //Do not do any loading
+		}
 		chum_set_easy_game(TRUE);
 		handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), "skill_easy");
 		}
 	else if (strcmp(name,"advanced")==0)
 		{
-		tangle_button_set_selected(tanglebutton,TRUE);
+		if (!chum_is_easy_game()){
+			main_menu_go_back_to_main_menu(NULL,NULL);
+			return TRUE; //Do not do any loading
+		}
 		chum_set_easy_game(FALSE);
 		handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), "skill_advanced");
 		}
