@@ -296,24 +296,10 @@ void singinggame_start_songselection(){
 
 	//////////////
 	//Change flag to corresponding language
-	ClutterActor* button;
-	ClutterActor* texture;
 	gchar *new_name = g_strdup_printf("%s/language_flag%s.png", DATA_DIR, selected_language); //name contains prefix _
-
 	//printf("looking for '%s'\n",new_name);
-	button = jammo_get_actor_by_id("songselection-language");
-	//Remove old texture
-	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), NULL);
-
-	//And put new
-	texture =  tangle_texture_new(new_name);
-	if (texture==NULL) {
-		g_free(new_name);
-		gchar *new_name = g_strdup_printf("%s/language_icon.png", DATA_DIR); //Default icon
-		texture =  tangle_texture_new(new_name);
-	}
-	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
 
+	tangle_texture_set_from_file(TANGLE_TEXTURE(jammo_get_actor_by_id("songselection-language-texture")),new_name);
 	g_free(new_name);
 	////////////
 
@@ -450,7 +436,6 @@ void singinggame_start_songselection(){
 	g_list_free(trick_list);
 
 	//printf("height_of_container:%f\n",height_of_container);
-	clutter_actor_set_size(container, 672.0, 480.0);
 	jammo_mentor_speak_once(jammo_mentor_get_default(),mentor_speech);
 
 
