@@ -368,7 +368,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		#ifdef MELODIC_CONTOUR
 		const gchar* selected_language=chum_get_selected_language();
 		//contour_cursor = moving thing
-		contour_cursor = clutter_texture_new();
+		contour_cursor = NULL;
 		gchar* filepath1;
 		filepath1 = g_strdup_printf("%s/cursor%s.png", song->fullpath, selected_language );
 		fd = open(filepath1,O_RDONLY);
@@ -382,16 +382,17 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 				g_free(message);
 				//contour_cursor = config_get_configured_actor(NULL,"contour_star");
 			} else {
-				clutter_texture_set_from_file (CLUTTER_TEXTURE (contour_cursor), filepath1, NULL);
+				contour_cursor = tangle_texture_new(filepath1);
 				close(fd);
 			}
 		} else {
-			clutter_texture_set_from_file (CLUTTER_TEXTURE (contour_cursor), filepath1, NULL);
+			contour_cursor = tangle_texture_new(filepath1);
 			close(fd);
 		}
 		g_free(filepath1);
 
-		clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_cursor);
+		if (contour_cursor)
+			clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_cursor);
 
 
 		//contour_trace_area
