@@ -126,9 +126,11 @@ ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(
 /* Actor for parameter is soundfamily-container.*/
 static void pause_actors_animation(ClutterActor *actor, gpointer user_data) {
 	//printf("pause\n");
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
-		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(actor), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		ClutterAnimation* animation = clutter_actor_get_animation(child);
 		if (animation) {
 			ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
 			clutter_timeline_pause(CLUTTER_TIMELINE(timeline));
@@ -139,12 +141,15 @@ static void pause_actors_animation(ClutterActor *actor, gpointer user_data) {
 /* Actor for parameter is soundfamily-container.
 */
 static void unpause_actors_animation(ClutterActor *actor, gpointer sequencer) {
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+
 	//printf("unpause\n");
 	if (jammo_sequencer_get_position(JAMMO_SEQUENCER(sequencer))) //position==0 => 'not playing'-state
 		return; //If sequencer is playing, we do not want start any animation
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(actor)); children; children = children->next) {
-		ClutterAnimation* animation = clutter_actor_get_animation (children->data);
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(actor), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		ClutterAnimation* animation = clutter_actor_get_animation(child);
 		if (animation) {
 			ClutterTimeline* timeline = clutter_animation_get_timeline(animation);
 			clutter_timeline_start(CLUTTER_TIMELINE(timeline));
@@ -309,7 +314,7 @@ Make colored rectangles and add them to given parent.
 Returns number of used slots (length of color_coding).
 white=# because it has special meaning. Samples can't be dropped on this slot. (TODO)
 */
-static int create_backing_track_color_coding(const gchar* color_coding, gfloat slot_size, gfloat y_offset,TangleWidget* parent) {
+static ClutterActor* create_backing_track_color_bar(const gchar* color_coding, gfloat slot_size, gfloat y_offset) {
 	ClutterActor* actor;
 	ClutterColor white  = { 255,255,255,   255 };
 	ClutterColor yellow = { 255, 255, 0,   255 };
@@ -321,6 +326,7 @@ static int create_backing_track_color_coding(const gchar* color_coding, gfloat s
 	ClutterColor violet = { 148,0,211,     255 };
 	ClutterColor pink   = { 255,105,180,   255 };
 
+	ClutterActor* parent = tangle_widget_new();
 	int max=strlen(color_coding);
 	int i;
 	for (i=0;i<max;i++)
@@ -345,7 +351,7 @@ static int create_backing_track_color_coding(const gchar* color_coding, gfloat s
 		g_object_set(actor, "width", slot_size, "height", 40.0, "x", i* slot_size, "y", 80.0+y_offset, NULL);
 		clutter_container_add_actor(CLUTTER_CONTAINER(parent), actor);
 		}
-	return max;
+	return parent;
 }
 
 
@@ -792,15 +798,14 @@ if (use_two_tracks) y_offset=80;
 	//Container for tracks (one or two) and backing_track
 	ClutterActor* container_for_tracks = jammo_get_actor_by_id("composition_game_container_for_tracks");
 
+	theme->color_bar = create_backing_track_color_bar(background_color_code,WIDTH_OF_SLOT,y_offset);
+	clutter_actor_set_position(theme->color_bar, 0.0, 0.0);
 
-	ClutterActor *container_for_backingtrack_blocks = tangle_widget_new();
-	clutter_actor_set_position(container_for_backingtrack_blocks, 0.0, 0.0);
-
-	int number_of_slots = create_backing_track_color_coding(background_color_code,WIDTH_OF_SLOT,y_offset,TANGLE_WIDGET(container_for_backingtrack_blocks));
-	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), container_for_backingtrack_blocks, NULL);
+	int number_of_slots = strlen(background_color_code);
+	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), theme->color_bar, NULL);
 
 	//Tune width of containers
-	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 38.0);
+	clutter_actor_set_size(theme->color_bar,number_of_slots*WIDTH_OF_SLOT, 38.0);
 	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
 
 	gchar* message = g_strdup_printf("tempo_factory (time_sig): %d, beats_per_minute: %d",tempo_factory,beats_per_minute);
@@ -906,6 +911,9 @@ if (use_two_tracks) y_offset=80;
 	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLL_ACTION, scroll_action, JAMMO_TYPE_CURSOR, cursor);
 	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault); //FIXME: this is not free'ed!
 
+	//Each time start track scrolled begin.
+	g_object_set(scroll_action, "offset-x", 0, NULL);
+
 	//Advanced-game: there are containers for samplebuttons, do not start hidden animations.
 	if (!chum_is_easy_game())
 		theme_stop_all_icon_animations(theme);
@@ -938,6 +946,8 @@ void delete_theme(jammo_theme* theme){
 		clutter_container_remove_actor(CLUTTER_CONTAINER(container_for_tracks),CLUTTER_ACTOR(theme->upper_track_view));
 	}
 
+	clutter_actor_destroy(theme->color_bar);
+
 
 	//Remove set of samplebuttons and all track_views and scrolling-actors etc.
 	clutter_actor_destroy(theme->container);
