@@ -133,6 +133,25 @@ if (!chum_is_easy_game()) {
 			//Clean list:
 			clutter_container_foreach(CLUTTER_CONTAINER(container), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
 
+			//Check is there need for scroller at all
+			TangleLayout* layout = tangle_widget_get_layout(TANGLE_WIDGET(container));
+			GList* trick_list = tangle_layout_get_tricks(layout);
+			ClutterActor* trick = trick_list->data;
+
+			//Three or less item fits without scrolling (we need they are 100px height and we have some 350px space)
+			if (number_of_pair_games<4) {
+				g_object_set(trick,"axis",TANGLE_SCROLL_NO_AXIS,NULL);
+			}
+			else {
+				g_object_set(trick,"axis",TANGLE_SCROLL_Y_AXIS,NULL);
+			}
+			g_list_free(trick_list);
+
+
+			//Each time start scroller not scrolled.
+			ClutterAction* scroll_action = tangle_actor_get_action_by_type(container,TANGLE_TYPE_SCROLL_ACTION);
+			g_object_set(scroll_action, "offset-y", 0, NULL);
+
 			ClutterActor* avatar_icon;
 			ClutterActor* theme_icon;
 			int counter=0;
@@ -150,9 +169,9 @@ if (!chum_is_easy_game()) {
 
 
 				avatar_icon=tangle_button_new_with_background_actor(tangle_texture_new("/opt/jammo/themes/city/110/beatbox.png")); //TODO: use avatar
-				g_object_set(avatar_icon, "x", 100.0,  "y", 100.0 *(counter+1), NULL);
+				g_object_set(avatar_icon, "x", 100.0,  "y", 100.0 *(counter), NULL);
 				guint * group_id = &(((gems_group_info*)(g_list_nth(pair_game_list, counter)->data))->id );
-				gchar* message = g_strdup_printf("pair game: counter %d, pair games %d, group_id %u\n", counter, number_of_pair_games, *group_id);
+				gchar* message = g_strdup_printf("pair game: counter %d, pair games %d, group_id %u", counter, number_of_pair_games, *group_id);
 				cem_add_to_log(message,J_LOG_NETWORK);
 				g_free(message);
 
@@ -169,13 +188,13 @@ if (!chum_is_easy_game()) {
 
 				theme_icon=tangle_button_new_with_background_actor(tangle_texture_new(theme_icon_name));
 				g_free(theme_icon_name);
-				g_object_set(theme_icon, "x", 200.0,  "y", 100.0 *(counter+1), "width", 400.0, "height", 80.0, NULL);
+				g_object_set(theme_icon, "x", 200.0,  "y", 100.0 *(counter), "width", 400.0, "height", 80.0, NULL);
 				tangle_widget_add(TANGLE_WIDGET(container), theme_icon, NULL);
 				tangle_actor_show(TANGLE_ACTOR(theme_icon));
 				counter++;
 			}
 
-			clutter_actor_set_size(container, 672.0, 100.0 * counter);
+
 		}
 		g_list_free(pair_game_list);
 		g_list_free(group_list);
