@@ -4,7 +4,7 @@
 #include "communitymenu.h"
 #include "community_utilities.h"
 #include "string.h"
-
+#include "../../cem/cem.h"
 
 static void end_avatar_view();
 
@@ -41,7 +41,7 @@ void start_avatar_editor(){
 
 	guint32 avatar_id = 0;
 
-	printf("Starting avatar editor\n");
+	cem_add_to_log("Starting avatar editor", J_LOG_DEBUG);
 
 	ClutterActor* mainview;
 	
@@ -106,18 +106,20 @@ void start_avatar_editor(){
 
 void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrumentBackground, char *widget){
 
-
+	gchar* default_body_filename = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/body_blue.png", DATA_DIR);
+	gchar* default_head_filename = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/heads/head_yellow.png", DATA_DIR);
+	gchar* avatarbg_filename = g_strdup_printf("%s/communitymenu/community_avatar_avatarbackground.png", DATA_DIR);
 
 	if(instrumentBackground == 0){
 
 	}
 
 	if(avatar->body == 0){
-		avatar->body = tangle_texture_new("/opt/jammo/communitymenu/AVATAR_PARTS/bodys/body_blue.png");
+		avatar->body = tangle_texture_new(default_body_filename);
 		clutter_actor_set_name(avatar->body, "body_blue.png");
 	}
 	if(avatar->head == 0){
-		avatar->head = tangle_texture_new("/opt/jammo/communitymenu/AVATAR_PARTS/heads/head_yellow.png");
+		avatar->head = tangle_texture_new(default_head_filename);
 	clutter_actor_set_name(avatar->head, "head_yellow.png");
 	}
 
@@ -136,7 +138,7 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 	if(avatar->instrument != 0){
 
 		if(instrumentBackground == 0){
-			instrumentBackground = tangle_texture_new("/opt/jammo/communitymenu/community_avatar_avatarbackground.png");
+			instrumentBackground = tangle_texture_new(avatarbg_filename);
 			clutter_actor_set_size(instrumentBackground, 110, 110);
 			clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), instrumentBackground);
 		}		
@@ -197,13 +199,20 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 	if(avatar->hair != 0)
 		clutter_actor_raise(avatar->hair, avatar->head);
 
+	g_free(default_body_filename);
+	g_free(default_head_filename);
+	g_free(avatarbg_filename);
+
 }
 
 static void pressed(ClutterActor *actor){
 
 	char *temp;
+	gchar* bodys_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/", DATA_DIR);
+	gchar* hairs_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/hairs/", DATA_DIR);
+	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
 
-	if(strstr(clutter_actor_get_name(actor), "/opt/jammo/communitymenu/AVATAR_PARTS/bodys")){
+	if(strstr(clutter_actor_get_name(actor), bodys_path)){
 		hairsInList = FALSE;
 		DESTROY_ACTOR(avatar.body);
 		avatar.body = tangle_texture_new(clutter_actor_get_name(actor));
@@ -211,7 +220,7 @@ static void pressed(ClutterActor *actor){
 		
 		}
 		
-	if(strstr(clutter_actor_get_name(actor), "/opt/jammo/communitymenu/AVATAR_PARTS/hairs")){
+	if(strstr(clutter_actor_get_name(actor), hairs_path)){
 	
 		DESTROY_ACTOR(avatar.hair);
 			
@@ -225,7 +234,7 @@ static void pressed(ClutterActor *actor){
 		clutter_actor_set_name(avatar.hair, clutter_actor_get_name(actor));
 		}	
 
-	if(strstr(clutter_actor_get_name(actor), "/opt/jammo/communitymenu/INSTRUMENTS")){
+	if(strstr(clutter_actor_get_name(actor), instruments_path)){
 	
 		hairsInList = FALSE;
 	
@@ -237,19 +246,23 @@ static void pressed(ClutterActor *actor){
 
 	set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 
+	g_free(bodys_path);
+	g_free(hairs_path);
+	g_free(instruments_path);
+
 }
 
 gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 
-	puts("changing body color");
+	cem_add_to_log("changing body color", J_LOG_DEBUG);
 	
 	clear_container(partsList);
 	
-	const char path[100] = "/opt/jammo/communitymenu/AVATAR_PARTS/bodys/";
-	
+	char path[100] = DATA_DIR;
+	strcat(path, "/communitymenu/AVATAR_PARTS/bodys/");
 	
 	if(!add_images_from_directory(path, partsList, (GCallback)pressed, 100, 100)){
-		puts("can't open directory containing avatar parts");
+		cem_add_to_log("can't open directory containing avatar parts", J_LOG_ERROR);
 		
 	}
 
@@ -258,10 +271,10 @@ gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 
 gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 
-	char path[150] = "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/";
-	
-	puts("changing hair color");
+	char path[150] = DATA_DIR;
+	strcat(path, "/communitymenu/AVATAR_PARTS/hairs/");
 	
+	cem_add_to_log("changing hair color", J_LOG_DEBUG);
 
 	hairColor = (hairColor+1) % NUMBEROFCOLORS;
 	
@@ -279,7 +292,7 @@ gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 		strcat(path, currentHairType);	     
 	
 		DESTROY_ACTOR(avatar.hair);	
-		avatar.hair = tangle_texture_new(path);puts(path);	
+		avatar.hair = tangle_texture_new(path);	
 		clutter_actor_set_name(avatar.hair, path);	
 		set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 
@@ -291,42 +304,46 @@ gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 	return TRUE;
 }
 
+
 gboolean change_hair_type_clicked(TangleActor *actor, gpointer data){
 	change_hair_type();
 	return TRUE;
 }
 
-static void change_hair_type() {
-	puts("changing hair type");
+
+void change_hair_type() {
+	
+	cem_add_to_log("changing hair type", J_LOG_DEBUG);
 	
 	hairsInList = TRUE;
 
 	clear_container(partsList);
 	
-	char path[100];
+	char path[100] = DATA_DIR;
 	
-	if(hairColor == BLACK) strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/black/");
-	if(hairColor == BLOND) strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/blond/");
-	if(hairColor == BLUE) strcpy(path,"/opt/jammo/communitymenu/AVATAR_PARTS/hairs/blue/");
-	if(hairColor == BROWN) strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/brown/");
-	if(hairColor == DARKBROWN) strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/darkbrown/");
-	if(hairColor == GRAY) strcpy(path,"/opt/jammo/communitymenu/AVATAR_PARTS/hairs/gray/");
-	if(hairColor == ORANGE) strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/orange/");
-	if(hairColor == VIOLET) strcpy(path,"/opt/jammo/communitymenu/AVATAR_PARTS/hairs/violet/");
-	if(hairColor == WHITE) strcpy(path,"/opt/jammo/communitymenu/AVATAR_PARTS/hairs/white/");
+	if(hairColor == BLACK) strcat(path, "/communitymenu/AVATAR_PARTS/hairs/black/");
+	if(hairColor == BLOND) strcat(path, "/communitymenu/AVATAR_PARTS/hairs/blond/");
+	if(hairColor == BLUE) strcat(path,"/communitymenu/AVATAR_PARTS/hairs/blue/");
+	if(hairColor == BROWN) strcat(path, "/communitymenu/AVATAR_PARTS/hairs/brown/");
+	if(hairColor == DARKBROWN) strcat(path, "/communitymenu/AVATAR_PARTS/hairs/darkbrown/");
+	if(hairColor == GRAY) strcat(path,"/communitymenu/AVATAR_PARTS/hairs/gray/");
+	if(hairColor == ORANGE) strcat(path, "/communitymenu/AVATAR_PARTS/hairs/orange/");
+	if(hairColor == VIOLET) strcat(path,"/communitymenu/AVATAR_PARTS/hairs/violet/");
+	if(hairColor == WHITE) strcat(path,"/communitymenu/AVATAR_PARTS/hairs/white/");
 
 		
 	if(!add_images_from_directory(path, partsList, (GCallback)pressed, 100, 100))
-		puts("can't open directory containing avatar parts");
+		cem_add_to_log("can't open directory containing avatar parts", J_LOG_ERROR);
 }
 
 gboolean change_head_clicked(TangleActor *actor, gpointer data){
 
-	char path[150] = "/opt/jammo/communitymenu/AVATAR_PARTS/heads/";
+	char path[150] = DATA_DIR;
+	strcat(path, "/communitymenu/AVATAR_PARTS/heads/");
 	
 	hairsInList = FALSE;
 
-	puts("changing head");
+	cem_add_to_log("changing head", J_LOG_DEBUG);
 	
 	clear_container(partsList);
 	
@@ -349,12 +366,15 @@ gboolean change_head_clicked(TangleActor *actor, gpointer data){
 
 gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 
-	puts("changing instrument");
+	cem_add_to_log("changing instrument", J_LOG_DEBUG);
+	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
 	
 	clear_container(partsList);
 
-	if(!add_images_from_directory("/opt/jammo/communitymenu/INSTRUMENTS/", partsList, (GCallback)pressed, 100, 100))
-		puts("can't open directory containing instruments");
+	if(!add_images_from_directory(instruments_path, partsList, (GCallback)pressed, 100, 100))
+		cem_add_to_log("can't open directory containing instruments", J_LOG_ERROR);
+
+	g_free(instruments_path);
 
 	return TRUE;
 }
