@@ -11,7 +11,7 @@
 #include "community_utilities.h"
 #include "../jammo.h"
 #include "../../meam/jammo-sample.h"
-
+#include "../../cem/cem.h"
 #include "../../configure.h"
 #include "../file_helper.h"
 #include "sequencer.h"
@@ -65,7 +65,7 @@ static void name_clicked(ClutterActor* actor) {
 		}else if(type == 1){
 			play_selected_loop(actor);
 		}else{
-			printf("Invalid loop name\n");
+			cem_add_to_log("Invalid loop name\n", J_LOG_ERROR);
 		}
 	}
 }
@@ -128,20 +128,17 @@ void rename_loop(ClutterActor *loopName, int type){
 	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 			gems_profile_manager_get_userid(NULL), oldpath);
 
-	printf("Path: %s\n", path);
-	printf("Filename is:%s\n", filename);
-
 	if(firstCall == TRUE){
 		firstCall = FALSE;
 		renaming_loop = TRUE;
-		printf("Renaming text...\n");
+		cem_add_to_log("Renaming text...", J_LOG_DEBUG);
 
 		clutter_text_set_editable (CLUTTER_TEXT(text), TRUE);
 		clutter_actor_set_reactive(text, TRUE);
 		clutter_actor_grab_key_focus(text);
 	}else{
 		firstCall = TRUE;
-		printf("Done.\n");
+		cem_add_to_log("Done.", J_LOG_DEBUG);
 
 		clutter_text_set_editable (CLUTTER_TEXT(text), FALSE);
 		clutter_actor_set_reactive(text, FALSE);
@@ -155,12 +152,11 @@ void rename_loop(ClutterActor *loopName, int type){
 			strcat(new_projects_name, "/");
 			strcat(new_projects_name, givenname);
 			strcat(new_projects_name, ".json");
-			printf("Newname: %s.\n", new_projects_name);
 
 			if(file_exist(path)){ //labelfile exists
 				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 							gems_profile_manager_get_userid(NULL), givenname);
-				printf("Newpath: %s\n", newpath);
+
 				rename(path, newpath);
 			}
 			rename(filename, new_projects_name);
@@ -175,12 +171,11 @@ void rename_loop(ClutterActor *loopName, int type){
 			strcat(newname, "/");
 			strcat(newname, givenname);
 			strcat(newname, ".ogg");
-			printf("Newname: %s.\n", newname);
 
 			if(file_exist(path)){ //labelfile exists
 				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 							gems_profile_manager_get_userid(NULL), givenname);
-				printf("Newpath: %s\n", newpath);
+
 				rename(path, newpath);
 			}
 			rename(filename, newname);
@@ -194,23 +189,25 @@ void rename_loop(ClutterActor *loopName, int type){
 
 void play_selected_loop(ClutterActor *actor){
 	
-	//TODO: add correct loop, this one is just to test the button
 	static JammoSample *sample = NULL;
 	const char *filename = clutter_actor_get_name(actor);
 
 	if(sample == NULL){
-		//songName = "/home/teppo/jammo10-jammo-data/data/jammo7-12_all/backingtracks/Sa_LaBamba_110_A.ogg";
-		puts("Starting loop");
+
+		cem_add_to_log("Starting loop", J_LOG_DEBUG);
 
 		if(actor == NULL){
-			sample = jammo_sample_new_from_file("/home/teppo/jammo10-jammo-data/data/jammo7-12_all/backingtracks/Sa_LaBamba_110_A.ogg");
+			cem_add_to_log("Cannot play file because selected actor is invalid", J_LOG_DEBUG);
 		}else{
-			printf("Now playing: %s\n", filename);
+			gchar * message = g_strdup_printf("Playing file: %s", filename);
+			cem_add_to_log(message, J_LOG_DEBUG);
+			g_free(message);
+
 			sample = jammo_sample_new_from_file(filename);
 		}
 		jammo_sample_play(sample);
 	}else{
-		puts("loop stop");
+		cem_add_to_log("loop stop", J_LOG_DEBUG);
 		jammo_sample_stop(sample);
 		g_object_unref(sample);
 		sample = NULL;
@@ -220,7 +217,7 @@ void play_selected_loop(ClutterActor *actor){
 
 void show_song_label(show_label_params *params){
 
-	puts("Starting record label view.");
+	cem_add_to_log("Starting record label view.", J_LOG_DEBUG);
 
 	FILE *file;
 	gchar data[200];	
@@ -293,8 +290,7 @@ time_type get_current_time(){
 	struct tm *ts;
 	gchar temp[80];
 
-	//to get current time and date
-	now = time(NULL);
+	now = time(NULL); //to get current time and date
 
 	//to format the time, "dd.mm.yy hh:mm"
 	ts = localtime(&now);
@@ -314,7 +310,11 @@ gboolean file_exist(gchar *filename)
   	if(stat(filename, &buffer) == 0){
     		return TRUE;
   	}else{
-		printf("Cannot find file: %s\n", filename);
+		gchar * message = g_strdup_printf("Cannot find file: %s", filename);
+
+		cem_add_to_log(message, J_LOG_ERROR);
+		g_free(message);		
+
     		return FALSE;
   	}
 }
@@ -522,9 +522,14 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 	hair_type = (avatar_id & 0xFF0000) >> 16;
 	instrument = (avatar_id & 0xFF000000) >> 24;
 
+	gchar* heads_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/heads/", DATA_DIR);
+	gchar* bodys_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/", DATA_DIR);
+	gchar* hairs_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/hairs/", DATA_DIR);
+	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
+
 	if(head != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/heads/");
+		strcpy(path, heads_path);
 		
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->head = tangle_texture_new(strcat(path, result[head-1]));	
@@ -534,7 +539,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 
 	if(body != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/bodys/");
+		strcpy(path, bodys_path);
 		
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->body = tangle_texture_new(strcat(path, result[body-1]));	
@@ -544,7 +549,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 	
 	if(hair_color != 0 && hair_type != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/");
+		strcpy(path, hairs_path);
 
 		community_open_and_arrange_dir(path, "DIR", result);
 		
@@ -563,13 +568,17 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 	
 	if(instrument != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/INSTRUMENTS/");
+		strcpy(path, instruments_path);
 		community_open_and_arrange_dir(path, ".png", result);
 		avatar->instrument = tangle_texture_new(strcat(path, result[instrument-1]));
 		clutter_actor_set_name(avatar->instrument, path);
 	
 	
 	}
+	g_free(heads_path);
+	g_free(bodys_path);
+	g_free(hairs_path);
+	g_free(instruments_path);
 
 	return TRUE;
 
@@ -589,10 +598,15 @@ gboolean community_save_avatar(Avatar* avatar){
 	char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN];
 	int i;
 	int numberOfImages = 0;
+
+	gchar* heads_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/heads/", DATA_DIR);
+	gchar* bodys_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/", DATA_DIR);
+	gchar* hairs_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/hairs/", DATA_DIR);
+	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
 	
 	if(avatar->head != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/heads/");
+		strcpy(path, heads_path);
 
 		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
 		
@@ -605,7 +619,7 @@ gboolean community_save_avatar(Avatar* avatar){
 	
 	if(avatar->body != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/bodys/");	
+		strcpy(path, bodys_path);	
 	
 		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
 		
@@ -619,7 +633,7 @@ gboolean community_save_avatar(Avatar* avatar){
 	
 	if(avatar->hair != 0){
 	
-		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/");
+		strcpy(path, hairs_path);
 		
 		numberOfImages = community_open_and_arrange_dir(path, "DIR", result);
 		
@@ -645,7 +659,7 @@ gboolean community_save_avatar(Avatar* avatar){
 	
 	if(avatar->instrument != 0){
 		
-		strcpy(path, "/opt/jammo/communitymenu/INSTRUMENTS/");
+		strcpy(path, instruments_path);
 		
 		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
 		
@@ -656,7 +670,6 @@ gboolean community_save_avatar(Avatar* avatar){
 		instrument = i+1;
 	
 	}
-
 	
 	guint32 id = 0;
 	
@@ -665,6 +678,11 @@ gboolean community_save_avatar(Avatar* avatar){
 	id += (body << 8);
 	id += (hair_type << 16);
 	id += (instrument << 24);
+
+	g_free(heads_path);
+	g_free(bodys_path);
+	g_free(hairs_path);
+	g_free(instruments_path);
 	
 	return gems_profile_manager_set_avatar_id(id);
 
