@@ -151,7 +151,7 @@ void helpdesk_show_question_view(ClutterActor *actor)
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
 	///TRANSLATORS: Leave %d as is because it is needed
-	printf(_("Showing Question: %d"), selectedQuestion);
+	cem_add_to_log(_("Showing Question: %d"), selectedQuestion);
 
 	start_thread_view(helpdesk_messages, "helpdesk", NULL, selectedQuestion);
 }
@@ -185,8 +185,8 @@ gboolean helpdesk_show_addquestion_view(TangleActor* actor, gpointer data) {
 		addquestion_questionTextField.handler_id = g_signal_connect_swapped(addquestion_questionTextField.text,
 							"text-changed", (GCallback)limit_line_count, &addquestion_questionTextField);		
 	}
-
-	else 	puts("can't find 'helpdesk-addquestion-view' ");
+	else 	
+		cem_add_to_log("can't find 'helpdesk-addquestion-view' ", J_LOG_ERROR);
 
 	return TRUE;
 }
@@ -250,13 +250,17 @@ gboolean helpdesk_add_question_clicked(TangleActor *actor, gpointer data){
 
 gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 {	
+	gchar* colorbar_path = g_strdup_printf("%s/communitymenu/colorbar13.png", DATA_DIR);
+	gchar* avatarBackground_path = g_strdup_printf("%s/communitymenu/community_avatarbackground_small.png", DATA_DIR);
+
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-	ClutterActor *colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar13.png");
+
+	ClutterActor *colorbar = tangle_texture_new(colorbar_path);
 	ClutterActor *avatarBackground = clutter_group_new();
 	ClutterActor *composer = tangle_button_new_with_background_actor(avatarBackground);
 	ClutterActor *commentButton = tangle_button_new_with_background_actor(tangle_texture_new(
 					"communitymenu/community_comment_icon.png"));
-	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new("/opt/jammo/communitymenu/community_avatarbackground_small.png"));
+	clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new(avatarBackground_path));
 
 	message *msg = data;
 
@@ -286,7 +290,7 @@ gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 
 	if(colorbar == NULL || commentButton == NULL)
 	{	
-		printf(_("NULL Pointer Detected!\n"));
+		cem_add_to_log("NULL Pointer Detected!", J_LOG_DEBUG);
 		return FALSE;	
 	}
 
@@ -309,6 +313,8 @@ gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 	g_signal_connect_swapped(CLUTTER_ACTOR(composer), "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
 	clutter_container_add_actor(questionslist.list, CLUTTER_ACTOR(listContainer));	
+	g_free(colorbar_path);
+	g_free(avatarBackground_path);
 
 	return TRUE;
 }
