@@ -623,7 +623,7 @@ static gboolean on_roller_button_press_down (ClutterActor *rect, ClutterEvent *e
 }
 
 ///destroy function
-void jammer_gohome_button (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean jammer_gohome_button (TangleActor* actor, gpointer data){
 	g_print("Jammer go home!\n");
 	g_source_remove(loop_id);
 	g_object_unref(G_OBJECT(jammerSample0));
@@ -635,14 +635,16 @@ void jammer_gohome_button (TangleAction *action, GObject *source, const gchar *t
 	//g_free(instr);
 	clutter_actor_hide(jammo_get_actor_by_id("jammer-view"));
 	return_to_fullsequencer_gui();
+	return TRUE;
 }
 
 ///mentor function
-void jammer_press_mentor (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean jammer_press_mentor (TangleActor* actor, gpointer data){
 	g_print("Jammer Mentor!\n");
+	return TRUE;
 }
 
-void jammer_press_play (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean jammer_press_play (TangleActor* actor, gpointer data){
 	g_print("Jammer play!\n");
 	if (!isJammerSeqPlaying){
 		//start playing
@@ -661,11 +663,11 @@ void jammer_press_play (TangleAction *action, GObject *source, const gchar *trig
 		jammo_sequencer_stop(jammer_sequencer);
 		tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("jammer_play_button")),FALSE);
 	}	
-	
+	return TRUE;
 }
 
 /*RECORD*/
-void jammer_press_rec (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean jammer_press_rec (TangleActor* actor, gpointer data){
 	if (!isJammerRecording){
 	//start recording
 		//first stop the sequencer if it plays
@@ -683,7 +685,8 @@ void jammer_press_rec (TangleAction *action, GObject *source, const gchar *trigg
 		isJammerRecording = FALSE;
 		tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("jammer_rec_button")),FALSE);
 	}
-	
+
+	return TRUE;
 }
 
 static gboolean timeout_func(gpointer data){ ///this runs at jammerFreq (in millisecs)
@@ -767,7 +770,7 @@ static void init_jammerinstr(ClutterActor *btnSet){
 	int posx = 0;
 	int i;
 	for (i=0;i<8;i++){
-		instr[i].instrumentImg = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, instr[i].avatarfile, NULL), NULL);
+		instr[i].instrumentImg = tangle_texture_new(g_build_filename(JAMMERIMGPATH, instr[i].avatarfile, NULL));
 		clutter_actor_set_size (instr[i].instrumentImg, 90, 90);
 		clutter_actor_set_position (instr[i].instrumentImg, posx,25);
 		clutter_container_add_actor (CLUTTER_CONTAINER (btnSet),instr[i].instrumentImg);
@@ -947,7 +950,7 @@ static void create_octave(ClutterActor *octSet, gchar *octavenum){
 		}
 		//////TEXTURE FILE
 		ClutterActor *octSet1_whiteKeysTexture;
-		octSet1_whiteKeysTexture = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_key_white-withbg.png", NULL), NULL);
+		octSet1_whiteKeysTexture = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_key_white-withbg.png", NULL));
 		clutter_actor_set_size (octSet1_whiteKeysTexture,77, 272);
 		clutter_actor_set_position (octSet1_whiteKeysTexture, 0, -204);
 		clutter_container_add_actor (CLUTTER_CONTAINER (whiteKey_container[i]), octSet1_whiteKeysTexture);
@@ -981,7 +984,7 @@ static void create_octave(ClutterActor *octSet, gchar *octavenum){
 					
 			//////TEXTURE FILE
 			ClutterActor *octSet1_blackKeysTexture;
-			octSet1_blackKeysTexture = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_key_black-withbg.png", NULL), NULL);
+			octSet1_blackKeysTexture = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_key_black-withbg.png", NULL));
 			clutter_actor_set_size (octSet1_blackKeysTexture,43, 200);
 			clutter_actor_set_position (octSet1_blackKeysTexture, 0, -150);
 			clutter_container_add_actor (CLUTTER_CONTAINER (blackKey_container[i]), octSet1_blackKeysTexture);
@@ -997,7 +1000,7 @@ start_jammer ()
 {
 	//init clutter
 	ClutterActor *stage;
-	stage = tangle_widget_new(); //TODO: define this and all other (clutter_texture_new_from_file) on jammer-view.json! --moved some to json
+	stage = tangle_widget_new(); //TODO: define this and all other (tangle_texture_new) on jammer-view.json! --moved some to json
 
 	//init jammer
 	g_print("starting jammer\n");
@@ -1018,28 +1021,28 @@ start_jammer ()
 	clutter_container_add_actor (CLUTTER_CONTAINER (stage), btnSet2);
 	clutter_actor_set_reactive (btnSet2, TRUE);
 	/*Up button right*/
-	ClutterActor *upBtn1 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_arrows_up.png", NULL), NULL);
+	ClutterActor *upBtn1 = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_arrows_up.png", NULL));
 	clutter_actor_set_size (upBtn1, 84, 23);
 	clutter_actor_set_position (upBtn1, 0,0);
 	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet2),upBtn1);
 	g_signal_connect (upBtn1, "button-press-event", G_CALLBACK (on_roller_button_press_up), NULL);
 	clutter_actor_set_reactive (upBtn1, TRUE);
 	/*Up button left*/
-	ClutterActor *upBtn2 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_arrows_up.png", NULL), NULL);
+	ClutterActor *upBtn2 = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_arrows_up.png", NULL));
 	clutter_actor_set_size (upBtn2, 84, 23);
 	clutter_actor_set_position (upBtn2, 0,260);
 	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet2),upBtn2);
 	g_signal_connect (upBtn2, "button-press-event", G_CALLBACK (on_roller_button_press_up), NULL);
 	clutter_actor_set_reactive (upBtn2, TRUE);
 	/*Down button right*/
-	ClutterActor *downBtn1 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_arrows_down.png", NULL), NULL);
+	ClutterActor *downBtn1 = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_arrows_down.png", NULL));
 	clutter_actor_set_size (downBtn1, 84, 23);
 	clutter_actor_set_position (downBtn1, 120,0);
 	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet2),downBtn1);
 	g_signal_connect (downBtn1, "button-press-event", G_CALLBACK (on_roller_button_press_down), NULL);
 	clutter_actor_set_reactive (downBtn1, TRUE);
 	/*Down button left*/
-	ClutterActor *downBtn2 = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "jammer_arrows_down.png", NULL), NULL);
+	ClutterActor *downBtn2 = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "jammer_arrows_down.png", NULL));
 	clutter_actor_set_size (downBtn2, 84, 23);
 	clutter_actor_set_position (downBtn2, 120,260);
 	clutter_container_add_actor (CLUTTER_CONTAINER (btnSet2),downBtn2);
@@ -1064,7 +1067,7 @@ start_jammer ()
 	//init kits
 	setSoundKit();
 	/*gui element*/
-	ClutterActor *chosenBtn = clutter_texture_new_from_file(g_build_filename(JAMMERIMGPATH, "chosen.png", NULL), NULL);
+	ClutterActor *chosenBtn = tangle_texture_new(g_build_filename(JAMMERIMGPATH, "chosen.png", NULL));
 	clutter_actor_set_size (chosenBtn, 130, 130);
 	clutter_actor_set_position (chosenBtn, 115,5);
 	clutter_container_add_actor (CLUTTER_CONTAINER (viewpoint3),chosenBtn);
