@@ -9,6 +9,7 @@ This file contains the functionality of JamMo Sounds menu.
 #include <string.h>
 #include "jammosounds.h"
 #include "community_utilities.h"
+#include "../../cem/cem.h"
 
 static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
 
@@ -21,7 +22,7 @@ void start_jammosounds(){
 
 	int numberOfLoops = 0; //this should contain the number of loops in the list
 
-	printf("Starting JamMoSounds\n");
+	cem_add_to_log("Starting JamMoSounds", J_LOG_DEBUG);
 
 	ClutterActor* mainview;
 	
@@ -54,22 +55,20 @@ void start_jammosounds(){
 	
 	}
 	else
-		puts("can't find 'jammosounds-view' ");
+		cem_add_to_log("can't find 'jammosounds-view' ", J_LOG_ERROR);
 }
 
 
-
-
-
-
-
 gboolean add_loop_to_list(char* name, int numberOfLoops){
-
-	ClutterActor* listImage = tangle_texture_new("/opt/jammo/communitymenu/community_jammosounds_bar.png");
+	
+	gchar* listImage_filename = g_strdup_printf("%s/communitymenu/community_jammosounds_bar.png", DATA_DIR);
+	gchar* importButton_filename = g_strdup_printf("%s/communitymenu/community_icon_toloopgame.png", DATA_DIR);
+	gchar* arrowImage_filename = g_strdup_printf("%s/communitymenu/community_rightarrow.png", DATA_DIR);
+	
+	ClutterActor* listImage = tangle_texture_new(listImage_filename);
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
-	ClutterActor *importButton = tangle_button_new_with_background_actor(tangle_texture_new(
-			"/opt/jammo/communitymenu/community_icon_toloopgame.png"));			
-	ClutterActor *arrowImage = tangle_texture_new("/opt/jammo/communitymenu/community_rightarrow.png");
+	ClutterActor *importButton = tangle_button_new_with_background_actor(tangle_texture_new(importButton_filename));			
+	ClutterActor *arrowImage = tangle_texture_new(arrowImage_filename);
 	ClutterActor *instrument;
 	ClutterActor *text;
 	ClutterActor *loopName;
@@ -80,17 +79,20 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	if(listItemHeight == 0)
 		listItemHeight = clutter_actor_get_height(listImage);
 
-
 	clutter_container_add_actor(listContainer, listImage);
 	//clutter_container_add_actor(listContainer, listImage);
+
+	g_free(listImage_filename);
+	g_free(importButton_filename);
+	g_free(arrowImage_filename);
 	
 	//TODO: add instrument icon depending on the instrument
-
-	instrument = tangle_texture_new("/opt/jammo/wheel_game/piano.png");  
+	gchar* instrument_filename = g_strdup_printf("%s/wheel_game/piano.png", DATA_DIR);
+	instrument = tangle_texture_new(instrument_filename);  
 	clutter_actor_set_position(instrument, 130, 0);
 	clutter_actor_set_height(instrument, listItemHeight);
 	clutter_container_add_actor(listContainer, instrument);
-	
+	g_free(instrument_filename);
 	
 	text = clutter_text_new_with_text(TEXT_NORMAL, "Loop name here");	
 	loopName = tangle_button_new_with_background_actor(text);
@@ -98,8 +100,6 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 
 	clutter_actor_set_position(loopName, 230, listItemHeight/5*2);
 	clutter_container_add_actor(listContainer, loopName);	
-
-	
 		
 	clutter_actor_set_position(arrowImage, 655, 15);
 	
@@ -117,10 +117,8 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
 	
-	
 	if(numberOfLoops <= 6)
 		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * numberOfLoops+1);	
-
 	else
 		clutter_actor_set_height(CLUTTER_ACTOR(list), listItemHeight * 6);		
 
@@ -164,9 +162,9 @@ void import_selected_loop(ClutterActor *loop){
 				
 		
 			if(loop == children->data){
-				puts("found it");
+				//TODO: import selected loop
 				break;
-				}
+			}
 		
 		}while(children->next != NULL);
 	
@@ -178,7 +176,7 @@ void import_selected_loop(ClutterActor *loop){
 	
 	//clutter_container_remove_actor(list, children->data); // JUST TESTING
 
-	puts("importing..");
+	cem_add_to_log("Importing loop...", J_LOG_DEBUG);
 
 	g_list_free(children);
 
