@@ -1,7 +1,7 @@
 /*
 License: GPLv2, read more from COPYING
 
-This file contains the functionality of help menu.
+This file contains the functionality of mysongs menu.
  */
 #include <tangle.h>
 #include <string.h>
@@ -13,6 +13,7 @@ This file contains the functionality of help menu.
 #include "../../gems/community_server_functions.h"
 #include "record_cover_tool.h"
 #include "../../configure.h"
+#include "../../cem/cem.h"
 #include "../file_helper.h"
 #include "../jammo-mentor.h"
 #include "single_thread.h"
@@ -27,7 +28,7 @@ ClutterActor *currentlyModifiedLabel = 0;
 
 void start_mysongs()
 {
-	puts("Starting Mysongs\n");
+	cem_add_to_log("Starting Mysongs", J_LOG_DEBUG);
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 
@@ -38,10 +39,11 @@ void start_mysongs()
 	if(mysongs_view)
 	{
 		clutter_actor_show(CLUTTER_ACTOR(mysongs_view));
+		songlist.list = 0;
 		mysongs_refresh_list();
 	}
 
-	else 	puts("can't find 'mysongs-view' ");
+	else 	cem_add_to_log("can't find 'mysongs-view' ", J_LOG_ERROR);
 }
 
 void mysongs_end_mysongs(){
@@ -53,7 +55,6 @@ void mysongs_end_mysongs(){
 		removing_song = FALSE;
 	}		
 
-
 }
 
 
@@ -73,7 +74,7 @@ gboolean mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 
 gboolean mysongs_mentor_clicked (TangleButton *tanglebutton, gpointer data)   
 {
-	printf("mentor clicked\n");
+	cem_add_to_log("mentor clicked", J_LOG_DEBUG);
 	return TRUE;
 }
 
@@ -108,23 +109,30 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	ClutterActor *labelButton = 0;
 	ClutterActor *labelBg = 0;
 	gchar* path;
+	char colorbar_path[80] = DATA_DIR;
+	char infoButton_path[100] = DATA_DIR;
 
 	switch (type)
 	{
 		case 0:
-			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar1.png");
+			strcat(colorbar_path, "/communitymenu/colorbar1.png");
+			colorbar = tangle_texture_new(colorbar_path);
 			break;
 		case 1:
-			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar4.png");
+			strcat(colorbar_path, "/communitymenu/colorbar4.png");
+			colorbar = tangle_texture_new(colorbar_path);
 			break;
 		case 2:
-			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar5.png");
+			strcat(colorbar_path, "/communitymenu/colorbar5.png");
+			colorbar = tangle_texture_new(colorbar_path);
 			break;
 		case 3:
-			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar7.png");
+			strcat(colorbar_path, "/communitymenu/colorbar7.png");
+			colorbar = tangle_texture_new(colorbar_path);
 			break;
 		default:
-			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar12.png");
+			strcat(colorbar_path, "/communitymenu/colorbar12.png");
+			colorbar = tangle_texture_new(colorbar_path);
 			break;
 	}
 
@@ -153,16 +161,18 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	}
 	filename_for_textbutton[j] = 0;
 
+	//TODO: change gems_profile_manager_get_userid(NULL) to use proper user id
+
 	command = g_strdup_printf("ls %s/label_%d_%s.csv 1> /dev/null 2> /dev/null", configure_get_jammo_directory(), 
 					gems_profile_manager_get_userid(NULL), filename_for_textbutton);
-	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL), filename_for_textbutton);
 
-	//NOTE: gems_profile_manager_get_userid(NULL) gives new id every time jammo is restarted!
+	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL), 
+					filename_for_textbutton);
 
-	puts(command);
-	puts(path);
+	gchar* labelButton_filename = g_strdup_printf("%s/communitymenu/community_cdlabel_small.png", DATA_DIR);
 
-	if(file_exist(path)/*system(command) == 0*/){ //labelfile already exists
+	if(file_exist(path)/*system(command) == 0*/){ // labelfile already exists
+		
 		label =  clutter_group_new();
 		
 		labelBg = clutter_rectangle_new_with_color(clutter_color_new(255,255,255,255));
@@ -190,15 +200,17 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 		
 		clutter_actor_set_size(labelButton, 50, 50);
 		clutter_actor_set_position(labelButton, 500, 15);
-	}else{
 
-		labelButton = tangle_button_new_with_background_actor(tangle_texture_new("/opt/jammo/communitymenu/community_cdlabel_small.png"));
+	}else{
+		labelButton = tangle_button_new_with_background_actor(tangle_texture_new(labelButton_filename));
 		clutter_actor_set_position(labelButton, 500, 15);
 	}
 	g_free(command);
+	g_free(labelButton_filename);
 
-	remove_button = tangle_button_new_with_background_actor(tangle_texture_new(
-			"/opt/jammo/backingtracks/button_cancel.png"));
+	gchar* remove_button_filename = g_strdup_printf("%s/backingtracks/button_cancel.png", DATA_DIR);
+
+	remove_button = tangle_button_new_with_background_actor(tangle_texture_new(remove_button_filename));
 
 	text = clutter_text_new_full(TEXT_NORMAL, filename_for_textbutton, &mysongs_text_color);
 
@@ -209,7 +221,8 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	clutter_text_set_max_length (CLUTTER_TEXT(text), 40);
 	clutter_text_set_single_line_mode (CLUTTER_TEXT(text), TRUE);
 
-	arrowImage = tangle_texture_new("/opt/jammo/communitymenu/community_rightarrow.png");
+	gchar* arrowImage_filename = g_strdup_printf("%s/communitymenu/community_rightarrow.png", DATA_DIR);
+	arrowImage = tangle_texture_new(arrowImage_filename);
 
 	listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
@@ -217,31 +230,32 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	switch(type)
 	{
 		case 0:
-			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
-				"/opt/jammo/communitymenu/community_backtosequencer.png"));
+			strcat(infoButton_path, "/communitymenu/community_backtosequencer.png");
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(infoButton_path));
 
-			g_signal_connect (CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK (start_sequencer_with_this_file), NULL);
+			g_signal_connect(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK (start_sequencer_with_this_file), CLUTTER_ACTOR(infoButton));
 			clutter_actor_set_position(infoButton, 690, 7);
 			break;
 		case 1:
-			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
-				"/opt/jammo/communitymenu/community_umsic_icon.png"));
+			strcat(infoButton_path, "/communitymenu/community_umsic_icon.png");
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(infoButton_path));
 
 			clutter_actor_set_position(infoButton, 690, 15);
 
-			g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment),  infoButton);
+			g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment), CLUTTER_ACTOR(infoButton));
 			
 			break;
 		case 3:
-			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
-				"/opt/jammo/communitymenu/community_comment_icon.png"));
+			strcat(infoButton_path, "/communitymenu/community_comment_icon.png");
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(infoButton_path));
 
-			g_signal_connect(infoButton, "clicked", G_CALLBACK(mysongs_get_comments), NULL);
+			g_signal_connect(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_get_comments), CLUTTER_ACTOR(infoButton));
 			clutter_actor_set_position(infoButton, 690, 15);				
 			break;
 	}
+
 	if(colorbar == NULL || infoButton == NULL || arrowImage == NULL){
-		printf("Failed to load Colorbar, Arrowimage or infoButton\n");
+		cem_add_to_log("Failed to load Colorbar, Arrowimage or infoButton", J_LOG_ERROR);
 		return FALSE;	
 	}
 
@@ -249,35 +263,35 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 		songlist.listItemHeight = clutter_actor_get_height(colorbar);
 
 	clutter_container_add_actor(listContainer, colorbar);	//Add components inside the container
-	//clutter_actor_set_position(infoButton, 690, 15);
 
 	if(labelButton != 0)
 	{
-		clutter_container_add_actor(listContainer, labelButton);
+		clutter_container_add_actor(listContainer, CLUTTER_ACTOR(labelButton));
 		clutter_actor_raise(labelButton, colorbar);
 		clutter_actor_set_name(labelButton, path);
-		g_signal_connect_swapped(labelButton, "clicked", G_CALLBACK(mysongs_label_button_clicked), labelButton);
+		g_signal_connect_swapped(CLUTTER_ACTOR(labelButton), "clicked", G_CALLBACK(mysongs_label_button_clicked), CLUTTER_ACTOR(labelButton));
 	}
 	clutter_actor_set_name(infoButton,filename);
-	clutter_container_add_actor(listContainer, infoButton);
 
 	clutter_actor_set_name(remove_button,filename);
 	clutter_actor_set_position(remove_button, 580, 15);
 	clutter_container_add_actor(listContainer, remove_button);
+	g_free(remove_button_filename);
 
-	clutter_actor_set_position(textButton, 60, 23);			
-	clutter_container_add_actor(listContainer, textButton);
+	clutter_actor_set_position(textButton, 60, 23);		
+	clutter_container_add_actor(listContainer, textButton);	
 	
 	clutter_actor_set_position(arrowImage, 653, 15);
 	clutter_container_add_actor(listContainer, arrowImage);
+	g_free(arrowImage_filename);
 	
-	clutter_container_add_actor(listContainer, infoButton);
+	clutter_container_add_actor(listContainer, CLUTTER_ACTOR(infoButton));
 	
-	g_signal_connect_swapped(textButton, "button-press-event", G_CALLBACK(song_name_press_action), textButton);
-	g_signal_connect_swapped(textButton, "button-release-event", G_CALLBACK(song_name_release_action), textButton);
+	g_signal_connect_swapped(CLUTTER_ACTOR(textButton), "button-press-event", G_CALLBACK(song_name_press_action), CLUTTER_ACTOR(textButton));
+	g_signal_connect_swapped(CLUTTER_ACTOR(textButton), "button-release-event", G_CALLBACK(song_name_release_action), CLUTTER_ACTOR(textButton));
 
-	g_signal_connect_swapped(CLUTTER_ACTOR(remove_button), "clicked", G_CALLBACK(mysongs_remove_song_view), textButton);
-	g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), filename);	
+	g_signal_connect_swapped(CLUTTER_ACTOR(remove_button), "clicked", G_CALLBACK(mysongs_remove_song_view), CLUTTER_ACTOR(textButton));
+	g_signal_connect_swapped(CLUTTER_ACTOR(label), "clicked", G_CALLBACK(show_song_label), filename);	
 
 	clutter_container_add_actor(songlist.list, CLUTTER_ACTOR(listContainer));
 	
@@ -301,34 +315,13 @@ void mysongs_get_comments(ClutterActor* song)
 
 void mysongs_comment(ClutterActor *actor)
 {
-	/*GList *children = clutter_container_get_children(songlist.list); //Get list of actors
-	GList *node = children;
+	const gchar * filename = clutter_actor_get_name(actor);
 
-	int index = 0;
-	int found = 0;
-	
-	while(node != NULL)
-	{
-		index++;
+	gchar * message = g_strdup_printf("Sending song \"%s\" to JamMo Songs...", filename);
+	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(message);
 
-		if(actor == node->data)
-		{*/
-			//TO-DO: Send song to JamMo Songs
-			const gchar * filename = clutter_actor_get_name(actor);
-			//printf("Found it. Index %d\n", index);
-			printf("Song is: %s\n", filename);
-			printf("Sending song to JamMo Songs...\n");
-
-			//sendJammoFile(filename);
-
-		/*	found = 1;
-			break;
-		}
-
-		node = node->next;
-	}
-
-	g_list_free(children);*/
+	//sendJammoFile(filename); //TODO: Send song to JamMo Songs
 }
 
 
@@ -346,19 +339,22 @@ void mysongs_delete_song(ClutterActor *actor)
 	}
 	songname[i] = 0;
 	
+	//TODO: change gems_profile_manager_get_userid(NULL) to use proper user id
 	gchar* label = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL), songname);
 
-	printf("Removing %s...\n", filename);
+	gchar * message = g_strdup_printf("Removing %s...", filename);
+	cem_add_to_log(message, J_LOG_DEBUG);
+	g_free(message);
 
 	if(remove(filename) != 0)
-    		printf("Error deleting file\n");
+    		cem_add_to_log("Error deleting file", J_LOG_ERROR);
   	else
-  		printf("File successfully deleted\n");
+  		cem_add_to_log("File successfully deleted", J_LOG_ERROR);
     		
     	if(remove(label) != 0)
-    		printf("Error deleting labelfile\n");
+    		cem_add_to_log("Error deleting labelfile", J_LOG_ERROR);
     	else	
-    		printf("Labelfile succesfully deleted\n");		
+    		cem_add_to_log("Labelfile succesfully deleted", J_LOG_ERROR);		
     		
 	g_free(label);
 
@@ -381,17 +377,18 @@ void mysongs_remove_song_view(ClutterActor *actor){
 
 	removing_song = TRUE;
 	remove_view = CLUTTER_CONTAINER(jammo_get_actor_by_id("mysongs-container"));
+
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
+	gchar* ok_button_filename = g_strdup_printf("%s/backingtracks/button_ok.png", DATA_DIR);
+	gchar* cancel_button_filename = g_strdup_printf("%s/backingtracks/button_cancel.png", DATA_DIR);
 
 	ClutterActor *text = CLUTTER_ACTOR(clutter_text_new_full(TEXT_CAPTION, "Remove?", &mysongs_text_color));
 	clutter_actor_set_position(text, 20, 60);
 	clutter_container_add_actor(listContainer, text);
 	
-	ClutterActor *ok_button = tangle_button_new_with_background_actor(tangle_texture_new(
-		"/opt/jammo/backingtracks/button_ok.png"));
+	ClutterActor *ok_button = tangle_button_new_with_background_actor(tangle_texture_new(ok_button_filename));
 
-	ClutterActor *cancel_button = tangle_button_new_with_background_actor(tangle_texture_new(
-		"/opt/jammo/backingtracks/button_cancel.png"));
+	ClutterActor *cancel_button = tangle_button_new_with_background_actor(tangle_texture_new(cancel_button_filename));
 
 	clutter_actor_set_position(ok_button, 170, 40);
 	clutter_container_add_actor(listContainer, ok_button);
@@ -399,10 +396,13 @@ void mysongs_remove_song_view(ClutterActor *actor){
 	clutter_actor_set_position(cancel_button, 260, 60);
 	clutter_container_add_actor(listContainer, cancel_button);
 
-	g_signal_connect_swapped(CLUTTER_ACTOR(ok_button), "clicked", G_CALLBACK(mysongs_delete_song), actor);
-	g_signal_connect_swapped(CLUTTER_ACTOR(cancel_button), "clicked", G_CALLBACK(mysongs_cancel_song_delete), remove_view);
+	g_signal_connect_swapped(CLUTTER_ACTOR(ok_button), "clicked", G_CALLBACK(mysongs_delete_song), CLUTTER_ACTOR(actor));
+	g_signal_connect_swapped(CLUTTER_ACTOR(cancel_button), "clicked", G_CALLBACK(mysongs_cancel_song_delete), CLUTTER_CONTAINER(remove_view));
 
 	clutter_container_add_actor(remove_view, CLUTTER_ACTOR(listContainer));
+
+	g_free(ok_button_filename);
+	g_free(cancel_button_filename);
 }
 
 void mysongs_label_button_clicked(ClutterActor *label){
@@ -426,12 +426,10 @@ void mysongs_refresh_list()
 	GList* projects = NULL;
 	GList* finalized = NULL;
 
-	puts("Refreshing list...");
-
+	cem_add_to_log("Refreshing list...", J_LOG_DEBUG);
+	
 	clear_container(songlist.list);
 
-	songlist.list = 0;
-
 	projects = file_helper_get_all_files(configure_get_projects_directory()); //Project-files
 	finalized = file_helper_get_all_files(configure_get_finalized_directory()); //Audio-files
 
@@ -452,10 +450,12 @@ void mysongs_refresh_list()
 
 	if(numberOfLoops <= 6)
 		clutter_actor_set_height(CLUTTER_ACTOR(songlist.list), songlist.listItemHeight * numberOfLoops);
-
-	else	clutter_actor_set_height(CLUTTER_ACTOR(songlist.list), songlist.listItemHeight * 6);
-
+	else	
+		clutter_actor_set_height(CLUTTER_ACTOR(songlist.list), songlist.listItemHeight * 6);
+	
 	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(songlist.list), TANGLE_TYPE_SCROLL_ACTION);
 
-	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), &songlist);	
+	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), songlist.list); // 2 warnings happens here
+
+
 }
