@@ -63,11 +63,13 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 
 
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
-		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		const gchar* name2 = clutter_actor_get_name(child);
 		if (strcmp(name,name2)==0){
-			track_view=TANGLE_WIDGET(children->data);
+			track_view=TANGLE_WIDGET(child);
 		}
 	}
 
@@ -114,7 +116,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 				clutter_actor_show(jammo_get_actor_by_id("singing-view"));
 				clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 				}
-			else
+			else if (name && strcmp(name,"BackingTrack")==0)
 			{
 			cem_add_to_log(" Backing_track pressed",J_LOG_USER_ACTION);
 			clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
@@ -161,11 +163,13 @@ gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer dat
 	TangleWidget* track_view=NULL;
 
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
-		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		const gchar* name2 = clutter_actor_get_name(child);
 		if (strcmp(name,name2)==0){
-			track_view=TANGLE_WIDGET(children->data);
+			track_view=TANGLE_WIDGET(child);
 		}
 	}
 
@@ -271,11 +275,13 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 	TangleWidget* track_view=NULL;
 
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(container)); children; children = children->next) {
-		const gchar* name2 = clutter_actor_get_name(CLUTTER_ACTOR(children->data));
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		const gchar* name2 = clutter_actor_get_name(child);
 		if (strcmp(name,name2)==0){
-			track_view=TANGLE_WIDGET(children->data);
+			track_view=TANGLE_WIDGET(child);
 		}
 	}
 
