@@ -20,31 +20,38 @@ This is the sequencer.
 #include "../jammo-mentor.h"
 
 static gboolean instructions_interrupted;
-void startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
 	instructions_interrupted=TRUE;
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	gamesmenu_show(); //When level starts, it suppose that gamesmenu is also visible
 	gamesmenu_start_first_task_on_this_level("level_sandbox_4loops");
+
+	return TRUE;
 }
 
-void startmenu_goto_gamesmenu (TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_goto_gamesmenu (TangleButton* tanglebutton, gpointer none){
 	instructions_interrupted=TRUE;
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	cem_add_to_log("From startmenu to gamesmenu clicked",J_LOG_USER_ACTION);
 	gamesmenu_show();
 	gamesmenu_start_instructions_for_level1();
+
+	return TRUE;
 }
 
-void startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none){
 	instructions_interrupted=TRUE;
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	cem_add_to_log("From startmenu to communitymenu clicked",J_LOG_USER_ACTION);
 	start_communitymenu();
 
+	return TRUE;
 }
 
-void startmenu_mentor_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_mentor_clicked(TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("On startmenu mentor clicked",J_LOG_USER_ACTION);
+
+	return TRUE;
 }
 static void startmenu_welcome_ready(){
 	instructions_interrupted=TRUE;
@@ -86,7 +93,7 @@ static void startmenu_welcomeB(JammoMentor* mentor, const gchar* speech, gboolea
 	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "here_games.spx", startmenu_welcomeC,NULL);
 }
 
-void startmenu_draw_version_information(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+void startmenu_draw_version_information(TangleActor* actor, gpointer data){
 	//Show version number: defined in configure.ac
 	ClutterActor* version_label =  jammo_get_actor_by_id( "startmenu-version-info");
 	clutter_text_set_font_name (CLUTTER_TEXT(version_label),"Luxi Mono 36");
@@ -106,19 +113,21 @@ static void startmenu_quitB(JammoMentor* mentor, const gchar* speech, gboolean i
 		clutter_main_quit();
 }
 
-void startmenu_quit (TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_quit (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("startmenu_quit-called",J_LOG_USER_ACTION);
 	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
 	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
 	instructions_interrupted=TRUE;
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "jammo_quitted.spx", startmenu_quitB,NULL);
+
+	return TRUE;
 }
 
 /*
 Whenever any view want return back to startmenu, this function can be used
 */
-void startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none){
+gboolean startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("startmenu_goto_startmenu-called",J_LOG_USER_ACTION);
 	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("fullsequencer-view")));
 	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
@@ -127,5 +136,7 @@ void startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none){
 	mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 	clutter_actor_show(jammo_get_actor_by_id("startmenu-view"));
+
+	return TRUE;
 }
 
