@@ -90,10 +90,11 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 	JammoTrack* track;
 
 	gboolean first_track = TRUE;
-	GList* children_view;
-	for (children_view = tangle_widget_get_children_readonly(TANGLE_WIDGET(sequencer_widget)); children_view; children_view = children_view->next) {
+	TangleActorIterator actor_iterator;
+	ClutterActor* track_view;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(sequencer_widget), &actor_iterator); (track_view = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 
-		ClutterActor* track_view = children_view->data;
 		/* //There are something non-track_views on container. FIXME
 		if (TANGLE_IS_SCROLLING_ACTOR(track_view)){
 			fprintf(ofp,"(scroller)\n");
@@ -131,18 +132,19 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 			g_object_get(track_view,"slot-width",&slot_size,NULL);
 			//printf("slot_size '%lf'\n",slot_size);
 
-			GList* children;
+			TangleActorIterator actor_iterator2;
+			ClutterActor* child;
 			JammoSampleButton* jsb;
 			gboolean first = TRUE;
-
-			for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next)
+	
+			for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator2); (child = tangle_actor_iterator_get_actor(&actor_iterator2)); tangle_actor_iterator_next(&actor_iterator2))
 				{
 				if (first)
 					fprintf(ofp,"\n");
 				else
 					fprintf(ofp,",\n");
 				first=FALSE;
-				jsb = JAMMO_SAMPLE_BUTTON(children->data);
+				jsb = JAMMO_SAMPLE_BUTTON(child);
 				//printf("x: '%lf' \n",clutter_actor_get_x(CLUTTER_ACTOR(jsb)));
 				//printf("slot: '%lf' \n",clutter_actor_get_x(CLUTTER_ACTOR(jsb))/slot_size);
 				fprintf(ofp,"\t\t{\n");
