@@ -155,16 +155,15 @@ Used when removing over network,
 */
 void jammo_editing_track_view_remove_jammo_sample_button_from_slot(JammoEditingTrackView* track_view, guint asked_slot) {
 	gfloat asked_x = asked_slot * track_view->priv->slot_width;
-	GList* children;
-	ClutterActor* actor = NULL;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
 
 	gfloat x;  //left side of actor
 	gfloat x2; //x2=x+width, right side of actor
 
 	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
-
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
-		actor = CLUTTER_ACTOR(children->data);
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		x = clutter_actor_get_x(actor);
 		x2 = x + clutter_actor_get_width(actor);
 		if (x<= asked_x && asked_x < x2) {
@@ -188,7 +187,8 @@ gboolean jammo_editing_track_view_get_editing_enabled(JammoEditingTrackView* tra
 }
 
 void jammo_editing_track_view_set_editing_enabled(JammoEditingTrackView* track_view, gboolean editing_enabled) {
-	GList* children;
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
 
 	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
 
@@ -196,8 +196,9 @@ void jammo_editing_track_view_set_editing_enabled(JammoEditingTrackView* track_v
 		track_view->priv->editing_enabled = editing_enabled;
 		
 		clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(track_view), TANGLE_TYPE_DROP_ACTION)), editing_enabled);
-		for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
-			clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(children->data), TANGLE_TYPE_DRAG_ACTION)), editing_enabled);
+	
+		for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+			clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(child, TANGLE_TYPE_DRAG_ACTION)), editing_enabled);
 		}
 		
 		g_object_notify(G_OBJECT(track_view), "editing-enabled");
@@ -691,16 +692,16 @@ static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer
 
 static gboolean check_if_overlapping(JammoEditingTrackView* track_view, ClutterActor* sample_button, guint slot_index) {
 	guint n_slots;
-	GList* children;
-	ClutterActor* actor = NULL;
+	TangleActorIterator actor_iterator;
+	ClutterActor* actor;
 	gfloat x;
 	
 	guint64 duration_of_one_slot= track_view->priv->slot_duration;
 	guint64 duration_of_sample = jammo_sample_get_duration(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(sample_button)));
 	n_slots = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
 
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
-		actor = CLUTTER_ACTOR(children->data);
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		x = clutter_actor_get_x(actor);
 		if (actor != sample_button &&
 		    x < slot_index * track_view->priv->real_slot_width &&
@@ -712,8 +713,7 @@ static gboolean check_if_overlapping(JammoEditingTrackView* track_view, ClutterA
 		actor = NULL;
 	}
 	if (!actor) {
-		for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
-			actor = CLUTTER_ACTOR(children->data);
+		for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 			x = clutter_actor_get_x(actor);
 			if (actor != sample_button &&
 			    x >= slot_index * track_view->priv->real_slot_width &&
