@@ -198,7 +198,7 @@ If file is not found (or some other error case) values are not modifed.
  -> Caller should set own defaults before calling,
  (or check against NULL)
 */
-static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang, gboolean* start_passive_mentor) {
+static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang, gboolean* start_passive_mentor, gboolean* start_advanced) {
 	JsonParser *parser;
 	parser = json_parser_new ();
 	g_assert (JSON_IS_PARSER (parser));
@@ -288,6 +288,10 @@ static void read_config_file(char* filename, gboolean* log_stdout, int* log_leve
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
 		*start_passive_mentor= json_node_get_boolean (node);
 
+	node = json_object_get_member (object, "START_WITH_ADVANCED");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		*start_advanced= json_node_get_boolean (node);
+
 	g_object_unref (parser);
 }
 
@@ -326,9 +330,10 @@ int main(int argc, char** argv) {
 	int log_level=J_LOG_NONE;
 	gchar* lang_of_mentor = g_strdup_printf("system");
 	gboolean start_passive_mentor = FALSE;
+	gboolean start_advanced = FALSE; //This affects only for 3-6 years game
 
 	gchar* setting_file = g_strdup_printf("%s/jammo.config",configure_get_jammo_directory());
-	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor,&start_passive_mentor);
+	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor,&start_passive_mentor,&start_advanced);
 	g_free(setting_file);
 
 	//LOGGING
@@ -345,6 +350,9 @@ int main(int argc, char** argv) {
 	TangleStylesheet* stylesheet;
 	gchar* filename;
 	ClutterActor* stage;
+#ifdef BUFFERER_ENABLED
+	ClutterActor* bufferer;
+#endif
 	GError* error = NULL;
 	GObject* object;
 	ClutterActor* actor;
@@ -429,26 +437,34 @@ int main(int argc, char** argv) {
 	script = clutter_script_new();
 	add_search_paths(script);
 	if (!(filename = clutter_script_lookup_filename(script, name_of_main_json))) {
-		g_critical("File '%s' not found.",name_of_main_json);
-		
+		message = g_strdup_printf("File '%s' not found.",name_of_main_json);
+		cem_add_to_log(message, J_LOG_FATAL);
+		g_free(message);
+
 		return 1;
 	}
 	if (!clutter_script_load_from_file(script, filename, &error)) {
-		g_warning("Could not load file '%s': %s", filename, error->message);
+		message = g_strdup_printf("Could not load file '%s': %s", filename, error->message);
+		cem_add_to_log(message, J_LOG_FATAL);
+		g_free(message);
 
 		return 2;
 	}
 	g_free(filename);
 	
 	if (!(object = clutter_script_get_object(script, "main"))) {
-		g_warning("Object 'main' not found from the file '%s'.",name_of_main_json);
-		
+		message = g_strdup_printf("Object 'main' not found from the file '%s'.",name_of_main_json);
+		cem_add_to_log(message, J_LOG_FATAL);
+		g_free(message);
+
 		return 3;
 	}
 	
 	if (!CLUTTER_IS_ACTOR(object)) {
-		g_warning("Object 'main' is not ClutterActor in the file '%s'.",name_of_main_json);
-		
+		message = g_strdup_printf("Object 'main' is not ClutterActor in the file '%s'.",name_of_main_json);
+		cem_add_to_log(message, J_LOG_FATAL);
+		g_free(message);
+
 		return 4;
 	}
 	
@@ -467,7 +483,14 @@ int main(int argc, char** argv) {
 	clutter_actor_set_size(stage, 800, 480);
 #endif
 
+#ifdef BUFFERER_ENABLED
+	bufferer = tangle_bufferer_new();
+	clutter_actor_set_size(bufferer, 800, 480);
+	clutter_container_add_actor(CLUTTER_CONTAINER(stage), bufferer);	
+	clutter_container_add_actor(CLUTTER_CONTAINER(bufferer), actor);
+#else
 	clutter_container_add_actor(CLUTTER_CONTAINER(stage), actor);
+#endif
 	
 	clutter_actor_show(stage);
 
@@ -500,40 +523,22 @@ int main(int argc, char** argv) {
 	if (start_passive_mentor)
 		jammo_mentor_set_passive(jammo_mentor_get_default(),TRUE);
 
-	if (!strcmp(application_name,"jammo3_6")) { //start jammo 3-6 years
-		cem_add_to_log("Will start 3-6 years game", J_LOG_DEBUG);
-		g_timeout_add(10, start_3_6_game,NULL);
-		g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
-	}
 
-	else if (!strcmp(application_name,"jammo7_12")) { //start jammo 7-12 years
+	if (!strcmp(application_name,"jammo7_12")) { //start jammo 7-12 years
 		cem_add_to_log("Will start 7-12 years game", J_LOG_DEBUG);
 		gems_set_callback_game_starter(group_composition_remote_game_starter);//callback to start group game over network
 	}
 
-	//These are only debug shortcuts:
-	//Started with name jammo: check commandline parameters
-	else {
-// 		if (argc==2 && strcmp(argv[1],"editor")==0) {
-// 			midi_editor_start_with_filename(NULL);
-// 		}
-// 		else if (argc==3 && strcmp(argv[1],"editor")==0) {
-// 			midi_editor_start_with_filename(argv[2]);
-// 		}
-		if (argc==2 && strcmp(argv[1],"sequencer")==0) {
-			clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
-			clutter_actor_hide(jammo_get_actor_by_id("startmenu-view"));
-		}
-// 		else if (argc==2 && strcmp(argv[1],"gamesmenu")==0) {
-// 			start_gamesmenu();
-// 		}
-// 		else if (argc==2 && strcmp(argv[1],"communitymenu")==0) {
-// 			start_communitymenu();
-// 		}
-		else { //Do not use this with commandline parameters
-			g_timeout_add(10, start_3_6_game,NULL);
-			g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
+	//if (!strcmp(application_name,"jammo3_6"))
+	else  { //start jammo 3-6 years
+		cem_add_to_log("Will start 3-6 years game", J_LOG_DEBUG);
+		if(start_advanced){
+			TangleProperties* properties;
+			properties = TANGLE_PROPERTIES(jammo_get_object_by_id("global_game_properties"));
+			tangle_properties_set_boolean(properties, "easy_game_level",FALSE);
 		}
+		g_timeout_add(10, start_3_6_game,NULL);
+		g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
 	}
 
 	g_free(application_name);
