@@ -144,7 +144,7 @@ gboolean pg_validate_gesture(gchar *password) {
 	return TRUE;
 }
 
-gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
+void pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 
 	//is_new 0 for reset password, 1 for existing password
 	if (is_new == 1) {
@@ -161,16 +161,16 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 			if(gems_profile_manager_authenticate_default_user(password) == LOGIN_OK)
 			{
 				pg_set_reset_success_screen(stage, PG_RESET_PASSWORD_SUCCESS);
-				return TRUE;
+				return;
 			}
 			else
 			{
 				pg_set_error_screen(stage, PG_RESET_PASSWORD_ERROR);
-				return TRUE;
+				return;
 			}
 		} else {
 			pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-			return TRUE;
+			return;
 		}
 
 	} else {
@@ -205,7 +205,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 				pg_re_enable_select_option_screen(stage);
 			}
 			
-			return TRUE;
+			return;
 		}
 		
 		switch(gems_profile_manager_authenticate_user(loginname,password))
@@ -229,18 +229,18 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 					// TODO show notification to user
 				}
 				
-				return TRUE;
+				return;
 			
 			// Login ok!
 			case LOGIN_OK:
 				clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 				clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
-				return TRUE;
+				return;
 			
 			// Invalid password
 			case LOGIN_INVALID_PASSWORD:
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-				return TRUE;
+				return;
 			
 			// Cannot read
 			case LOGIN_PROFILE_READ_ERROR:
@@ -272,26 +272,26 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 					pg_re_enable_select_option_screen(stage);
 				}
 				
-				return TRUE;
+				return;
 			
 			// Should not happen - something is really wrong ...
 			case LOGIN_CANNOT_INIT_PASSWD:
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-				return TRUE;
+				return;
 			// Should not happen - something is really wrong ...
 			case LOGIN_CANNOT_INIT_SECURITY:
 				if(!gems_login_username_forced()) gems_clear_login_username();
 				pg_re_enable_select_option_screen(stage);
-				return TRUE;
+				return;
 			// Should not happen - something is really wrong ...
 			case LOGIN_INVALID_PARAMS:
 				if(!gems_login_username_forced()) gems_clear_login_username();
 				pg_re_enable_select_option_screen(stage);
-				return TRUE;
+				return;
 			default:
 				// Go to error screen if other error occurs
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-				return TRUE;
+				return;
 		}
 
 		if (strcmp(password, user_passwd) == 0) {
@@ -300,7 +300,7 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		} else {
 			pg_set_error_screen(stage, PG_PASSWORD_ERROR);
 		}
-		return TRUE;
+		return;
 	}
 }
 
