@@ -45,6 +45,10 @@ void configure_init_directories(gboolean small_game){
 		make_directory(COMPOSITIONS_DIRECTORY);
 		make_directory(SINGINGS_DIRECTORY);
 
+		gchar* recorded_waws = g_strdup_printf("%s/wavs",SINGINGS_DIRECTORY);
+		make_directory(recorded_waws);
+		g_free(recorded_waws);
+
 		//file for pen-gesture-login
 		gchar* cmd;
 		cmd = g_strdup_printf("touch %s/pg-passwords",configure_get_jammo_directory());
@@ -85,7 +89,8 @@ void configure_init_directories(gboolean small_game){
 			fprintf(ofp,"\"LOG_NETWORK_DEBUG\" : true,\n");
 			fprintf(ofp,"\"LOG_MENTOR_SPEECH\" : true,\n");
 			fprintf(ofp,"\"MENTOR_LANGUAGE\" : \"system\",\n");
-			fprintf(ofp,"\"START_WITH_PASSIVE_MENTOR\" : false\n");
+			fprintf(ofp,"\"START_WITH_PASSIVE_MENTOR\" : false,\n");
+			fprintf(ofp,"\"START_WITH_ADVANCED\" : false\n");
 			fprintf(ofp,"}\n");
 			fclose(ofp);
 		}
