@@ -188,7 +188,7 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 					ph_c_connection_get_remote_address(conn),ph_c_connection_get_device_checksum(conn));
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
-				
+			
 				data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_device_get_checksum(device), ERROR_CONNECTION);
 				ph_c_connection_delete(conn); // disconnects and deletes
 				conn = NULL;
@@ -200,14 +200,30 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 					ph_c_connection_get_remote_address(conn));
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
-				
+			
 				logmsg = g_strdup_printf("bytes: %d [%d|%d|%d]", msg->length, ntohs(*(guint16*)&msg->message[0]),ntohl(*(guint32*)&msg->message[2]),ntohs(*(guint16*)&msg->message[6]));
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
-				
+			
 				// New item in JAMMO_WAITING_REQUEST state
 				gems_connection* new_item = gems_new_gems_connection(conn, 0, 0, JAMMO_WAITING_REQUEST, 0);
+
+				if(ph_c_device_has_service(device, MENTOR_SERVICE_NAME)==TRUE)
+				{
+					// No connection to teacher
+					if(!gems_teacher_connection_is_connected())	gems_get_data()->teacher_connection->connection=new_item;
+					// connection to teacher exists
+					else
+					{
+						cem_add_to_log("Teacher device tried to connect when connection to a teacher already exists", J_LOG_DEBUG);
+						data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_device_get_checksum(device), ERROR_CONNECTION);
+						gems_clear_gems_connection(new_item);
+						return rval;
+					}
+				}
+
 				data->communication->connecting = g_list_append(data->communication->connecting, new_item);
+
 				rval = TRUE;
 			}
 			gems_clear_message(msg);
@@ -727,7 +743,7 @@ gint gems_communication_process_connected()
 	if(data->communication == NULL) return FALSE;
 	
 	// Check if we have a teacher connection
-	if(gems_teacher_connection_is_connected()) do_teacher_check = TRUE;
+	if(gems_teacher_connection_is_connected()) do_teacher_check = FALSE;
 	
 	iterator = g_list_first(data->communication->connections);
 	while(iterator || do_teacher_check)
@@ -1630,10 +1646,10 @@ gboolean gems_teacher_connection_disconnect()
 	// gems_connection exists
 	if(data->teacher_connection->connection != NULL)
 	{
-		gems_clear_gems_connection(data->teacher_connection->connection);
+		//gems_clear_gems_connection(data->teacher_connection->connection);
 		data->teacher_connection->connection = NULL;
 		
-		data->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
+		//data->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 		
 		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected. Teacher search re-enabled.");
 		cem_add_to_log(logmsg,J_LOG_NETWORK);
@@ -1654,7 +1670,7 @@ void gems_clear_teacher_connection()
 	// gems_connection exists
 	if(data->teacher_connection->connection != NULL)
 	{
-		gems_clear_gems_connection(data->teacher_connection->connection);
+		//gems_clear_gems_connection(data->teacher_connection->connection);
 		data->teacher_connection->connection = NULL;
 		
 		gchar* logmsg = g_strdup_printf("gems_clear_teacher_connection: connection to teacher was disconnected");
@@ -1734,6 +1750,14 @@ gint gems_communication_search_teacher()
 		// Go through list - there should be only one teacher
 		for( ; ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
 		{
+			//Teacher connection is one of the existing jammo connections - mark it as data->teacher_connection
+			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
+			data->teacher_connection->connection=gems_communication_get_connection(data->communication->connections, ph_c_device_get_checksum(dev));
+
+			logmsg = g_strdup_printf("gems_communication_search_jammos: Connected to new Mentor enabled device %s/%d", ph_c_device_get_name(dev),ph_c_device_get_checksum(dev));
+			cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+			g_free(logmsg);
+			/*
 			// Get the device
 			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
 			
@@ -1754,7 +1778,7 @@ gint gems_communication_search_teacher()
 					// Connection established, leave
 					break;
 				}
-			}
+			}*/
 		} // for
 		// Delete the iterator
 		ph_c_delete_device_iterator(iterator);
