@@ -355,7 +355,7 @@ void jammo_gems_cleanup()
 	g_free(logmsg);
 	
 	// Remove timeout functions
-	for(gint i = 0; i < TO_FUNCTIONS; i++) g_source_remove(components->timeout_functions[i]);
+	for(gint i = 0; i < TO_FUNCTIONS; i++) if(components->timeout_functions[i] != 0) g_source_remove(components->timeout_functions[i]);
 	
 	if(components->pm != NULL) profilemanager_delete_manager(components->pm);
 	
@@ -1240,7 +1240,7 @@ void gems_enable_network_timeout_functions()
 	gems_get_data()->timeout_functions[6] = g_timeout_add_full(G_PRIORITY_HIGH,500,(GSourceFunc)gems_communication_process_rejected, NULL, NULL);
 	gems_get_data()->timeout_functions[7] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_request_groups, NULL, NULL);
 	gems_get_data()->timeout_functions[8] = g_timeout_add_full(G_PRIORITY_HIGH,350,(GSourceFunc)gems_communication_sanitize_grouplist, NULL, NULL);
-	gems_get_data()->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,1000,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
+	//gems_get_data()->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,1000,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 }
 
 void gems_register_services()
