@@ -1032,6 +1032,39 @@ gems_message* gems_create_message_control_set_login_name(gchar* username)
 	return msg;
 }
 
+gems_message* gems_create_message_control_force_login(gchar* password, guint8 passlen)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + passlen + 1 + 1;
+	
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	
+	memset(msg->message,'\0',msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(CONTROL_FORCE_LOGIN);
+	position = position + sizeof(guint16);
+	
+	// passlength
+	*(guint8*)&msg->message[position] = passlen;
+	position++;
+
+	// password
+	g_memmove(&msg->message[position],password,passlen);
+	
+	return msg;
+}
+
 gems_message* gems_create_message_control_get_login()
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
