@@ -44,6 +44,10 @@ gboolean gems_service_control_process_request(gems_connection* element)
 						break;
 					case CONTROL_GET_LOGIN:
 						gems_service_control_handle_get_login(data,element);
+						break;
+					case CONTROL_FORCE_LOGIN:
+						gems_service_control_handle_force_login(data,element);
+						break;
 					default:
 						break;
 				}
@@ -183,3 +187,21 @@ void gems_service_control_handle_get_login(gems_components* data, gems_connectio
 	else cem_add_to_log("gems_service_control_handle_get_login: wrote login name reply to teacher", J_LOG_NETWORK_DEBUG);
 
 }
+
+void gems_service_control_handle_force_login(gems_components* data, gems_connection* element)
+{
+	guint position = sizeof(guint16)+sizeof(guint32)+sizeof(guint16);
+	guint8 length = *(guint8*)&element->nwbuffer[position];
+	position++;
+	
+	gchar* password = gems_connection_get_data(element,position,length);
+
+	if(gems_get_login_username())
+	{
+		if(gems_profile_manager_authenticate_user(gems_get_login_username(),password) == LOGIN_OK) cem_add_to_log("forced login: succesfully logged in",J_LOG_DEBUG);
+		else cem_add_to_log("forced login: cannot login",J_LOG_DEBUG);
+	}
+
+	g_free(password);
+}
+
