@@ -17,8 +17,11 @@
 #include "communication.h"
 #include "../cem/cem.h"
 
+static void empty_callback_profile(jammo_profile_container* prof){}
+
 gems_service_profile* gems_service_profile_init()
 {
+	teacher_server_callback_new_profile=empty_callback_profile;
 	gems_service_profile* data = (gems_service_profile*)g_malloc(sizeof(gems_service_profile));
 	data->enabled = FALSE;
 	data->port = 0;
@@ -155,7 +158,42 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 			
 			success = TRUE;
 			break;
-		//case PROFILE_FULL:
+		case PROFILE_FULL:
+			position = sizeof(gint16)+sizeof(gint32)+sizeof(gint16);
+			
+			gchar* username = gems_connection_get_char(element,position); // do not free, points to username in buffer!!
+			position = position + strlen(username) + 1;
+			
+			guint32 userid = gems_connection_get_32(element,position);
+			position = position + sizeof(guint32);
+			
+			guint16 uage = gems_connection_get_16(element,position);
+			position = position + sizeof(guint16);
+			
+			guint32 avatarid = gems_connection_get_32(element,position);
+			position = position + sizeof(guint32);
+			
+			gchar* firstname = gems_connection_get_char(element,position); // do not free, points to username in buffer!!
+			position = position + strlen(firstname) + 1;
+			
+			gchar* lastname = gems_connection_get_char(element,position); // do not free, points to username in buffer!!
+			position = position + strlen(lastname) + 1;
+			
+			guint32 points = gems_connection_get_32(element,position);
+			
+			gchar* logmsg = g_strdup_printf("Got full profile: userid:%u username: %s age:%d fullname:%s %s points:%u avatar:%u", 
+					userid,username,uage,firstname,lastname,points,avatarid);
+			cem_add_to_log(logmsg,J_LOG_INFO);
+			g_free(logmsg);
+
+
+			gchar* bs=g_strdup_printf("1");//to be used in gems_teacher_server_create_profile() as password and authlevel
+			jammo_profile_container* prof = gems_teacher_server_create_profile(PROF_TYPE_REMOTE, userid, username, bs, bs, firstname,lastname, uage, avatarid);
+			prof->points = points;
+			teacher_server_callback_new_profile(prof);
+			success = TRUE;
+			
+			break;
 		default:
 			success = FALSE;
 			break;
@@ -281,3 +319,6 @@ gboolean gems_service_profile_process_profile_upload(gems_connection* element)
 	
 	return success;
 }
+void gems_service_profile_set_callback_profile(void (*func_ptr)(jammo_profile_container* prof) ) {
+	teacher_server_callback_new_profile=func_ptr;
+}
