@@ -472,33 +472,40 @@ static void process_float(GstJammoLooper * src) {
 	}
 
 	while (loop) {
-		if (src->time > loop->start) {
-			if (loop->sfinfo.channels==1) {
-				new_frames=sf_read_float(loop->sndfileptr, &(src->floatbuffer[read_frames]), src->generate_samples_per_buffer/2-read_frames);
-				// copy to two channels
-				for (i=read_frames+new_frames-1; i>=read_frames; i--) {
-					src->floatbuffer[read_frames+2*i+1]=src->floatbuffer[read_frames+i];
-					src->floatbuffer[read_frames+2*i]=src->floatbuffer[read_frames+i];
-				}
-				//printf("last new %d, first new %d\n", read_frames+new_frames-1, read_frames);
-				//printf("last stereo %d, first stereo %d\n", read_frames+new_frames-1+new_frames);
-				read_frames+=new_frames*2;
-			}
-			else {
-				/* 2 channels */
-				read_frames+=sf_read_float(loop->sndfileptr, &(src->floatbuffer[read_frames]), src->generate_samples_per_buffer-read_frames);
-			}
-		}
-		else {
+		if (src->time <= loop->start) {
 			break;
 		}
-		if (read_frames*2 < src->generate_samples_per_buffer) {
-			src->sample_index+=1;
-			loop = (LooperLoop *)g_list_nth_data(src->loops, src->sample_index);
+		/* 1 channel. MONO */
+		if (loop->sfinfo.channels==1) {
+			new_frames=sf_read_float(loop->sndfileptr, &(src->floatbuffer[read_frames]), src->generate_samples_per_buffer/2-read_frames);
+			// copy to two channels
+			for (i=read_frames+new_frames-1; i>=read_frames; i--) {
+				//Boundary check
+				int index1=read_frames+2*i+1;
+				if (index1>=src->generate_samples_per_buffer)
+						index1=src->generate_samples_per_buffer-1;
+				int index2=read_frames+2*i;
+				if (index2>=src->generate_samples_per_buffer)
+						index2=src->generate_samples_per_buffer-1;
+
+				src->floatbuffer[index1]=src->floatbuffer[read_frames+i];
+				src->floatbuffer[index2]=src->floatbuffer[read_frames+i];
+			}
+			//printf("last new %d, first new %d\n", read_frames+new_frames-1, read_frames);
+			//printf("last stereo %d, first stereo %d\n", read_frames+new_frames-1+new_frames);
+			read_frames+=new_frames*2;
 		}
 		else {
+			/* 2 channels. STEREO */
+			read_frames+=sf_read_float(loop->sndfileptr, &(src->floatbuffer[read_frames]), src->generate_samples_per_buffer-read_frames);
+		}
+
+		if (read_frames*2 >=  src->generate_samples_per_buffer) {
 			break;
 		}
+
+		src->sample_index+=1;
+		loop = (LooperLoop *)g_list_nth_data(src->loops, src->sample_index);
 	}
 }
 
@@ -941,6 +948,8 @@ static void gst_jammo_looper_set_property (GObject * object, guint prop_id,
 		  		g_free(src->pitch);
 		  		src->pitch=NULL;
 		  	}
+				if (src->pitch)
+					g_free(src->pitch);
 		    src->pitch = g_strdup_printf("%s",g_value_get_string(value));
 		    //printf("pitch changed to %s\n", src->pitch);
 				for (i=0;i<g_list_length(src->loops);i++) {
