@@ -973,19 +973,19 @@ static gboolean gst_jammo_sampler_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
   /* allocate a new buffer suitable for this pad */
   switch (src->format) {
     case GST_JAMMO_SAMPLER_FORMAT_S16:
-      printf("format is now gint16\n");
+      //printf("format is now gint16\n");
       src->sample_size = sizeof (gint16);
       break;
     case GST_JAMMO_SAMPLER_FORMAT_S32:
-      printf("format is now gint32\n");
+      //printf("format is now gint32\n");
       src->sample_size = sizeof (gint32);
       break;
     case GST_JAMMO_SAMPLER_FORMAT_F32:
-      printf("format is now gfloat32\n");
+      //printf("format is now gfloat32\n");
       src->sample_size = sizeof (gfloat);
       break;
     case GST_JAMMO_SAMPLER_FORMAT_F64:
-      printf("format is now gfloat32\n");
+      //printf("format is now gfloat32\n");
       src->sample_size = sizeof (gdouble);
       break;
     default:
