@@ -393,11 +393,11 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
 	// open blow sound file for flute like slider
 	char * path=NULL;
 	path=g_strdup_printf("%s%s",SLIDER_FOLDER,"slider_blow.wav");
-	printf("opening file %s\n", path);
+	//printf("opening file %s\n", path);
 	memset(&(src->blow_file_info), 0, sizeof(SF_INFO));
 	src->blow_file = sf_open(path, SFM_READ, &(src->blow_file_info));
 	if (src->blow_file==NULL) {
-		printf("opening failed\n");
+		printf("slider-error: opening file '%s' failed\n",path);
 	}
 	else {
 		// allocate buffer
@@ -410,7 +410,8 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
 		}
 		sf_close(src->blow_file);
 	}
-	
+	g_free(path);
+
 	src->blow_accumulator=0.0;
 	src->blow_loop_start=5000;
 	src->blow_loop_end=40000;
@@ -976,14 +977,14 @@ static gboolean gst_jammo_slider_start (GstBaseSrc * basesrc)
 
   //realtime recording
   if (src->recording) {
-    printf("DEBUG:gstjammoslider: recording mode\n");
+    //printf("DEBUG:gstjammoslider: recording mode\n");
 		jammo_slider_event_free_glist(&(src->eventlist));
     src->eventlist=NULL;
 		src->time_of_last_stored_event=0;
   }
   //playback
   else  {
-    printf("DEBUG:gstjammoslider: not recording, playback\n");
+    //printf("DEBUG:gstjammoslider: not recording, playback\n");
 
     src->playback_index_for_event=0;
 
@@ -1303,7 +1304,7 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 			}
 
 			else { //adding non-realtime (nothing special)
-				printf("non-realtime\n");
+				//printf("non-realtime\n");
 				timestamp=event->timestamp;
 			}
 
