@@ -259,6 +259,8 @@ static void jammo_instrument_track_class_init(JammoInstrumentTrackClass* instrum
 
 
 void jammo_instrument_track_add_jammo_midi_event(JammoInstrumentTrack* instrument_track, JammoMidiEvent* event) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	g_object_set(G_OBJECT(instrument_track->priv->element), "add-event", event, NULL);
 }
 
@@ -271,7 +273,11 @@ Example usage:
 jammo_instrument_track_add_event(instrument_track,'e', 4, TRUE, 4081683703);
 */
 void jammo_instrument_track_add_event(JammoInstrumentTrack* instrument_track, char note, JammmoMidiEventType type, GstClockTime timestamp) {
-	JammoMidiEvent* new_event = malloc(sizeof(JammoMidiEvent));
+	JammoMidiEvent* new_event;
+
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+	
+	new_event = malloc(sizeof(JammoMidiEvent));
 	new_event->note = note;
 	new_event->timestamp = timestamp;
 	new_event->type = type;
@@ -282,8 +288,11 @@ void jammo_instrument_track_add_event(JammoInstrumentTrack* instrument_track, ch
 /*This deletes always both start and end events!
 */
 void jammo_instrument_track_remove_event(JammoInstrumentTrack* instrument_track, char note, GstClockTime timestamp) {
+	JammoMidiEvent* new_event;
 
-	JammoMidiEvent* new_event = malloc(sizeof(JammoMidiEvent));
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+	
+	new_event = malloc(sizeof(JammoMidiEvent));
 	new_event->note = note;
 	new_event->timestamp = timestamp;
 
@@ -295,8 +304,12 @@ void jammo_instrument_track_remove_event(JammoInstrumentTrack* instrument_track,
 Debug. Prints all events in this track.
 */
 void jammo_instrument_track_dump_notes(JammoInstrumentTrack* instrument_track){
-	GList* list= jammo_instrument_track_get_event_list(JAMMO_INSTRUMENT_TRACK(instrument_track));
+	GList* list;
 	JammoMidiEvent* n;
+	
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
+	list = jammo_instrument_track_get_event_list(JAMMO_INSTRUMENT_TRACK(instrument_track));
 
 	printf("Track:\n");
 	for (; list; list = list->next) {
@@ -312,11 +325,15 @@ If you have track in recordmode (=realtime), just call this and it will put time
 time and starting time of track.
 */
 void jammo_instrument_track_note_on_realtime(JammoInstrumentTrack* instrument_track, char note) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	jammo_instrument_track_add_event(instrument_track, note, JAMMOMIDI_NOTE_ON, 18446744073709551615ULL); //MAX
 }
 
 //see previous
 void jammo_instrument_track_note_off_realtime(JammoInstrumentTrack* instrument_track, char note) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	jammo_instrument_track_add_event(instrument_track, note, JAMMOMIDI_NOTE_OFF, 18446744073709551615ULL);
 }
 
@@ -327,21 +344,30 @@ static void jammo_instrument_track_init(JammoInstrumentTrack* instrument_track)
 
 
 void jammo_instrument_track_set_realtime(JammoInstrumentTrack* instrument_track, gboolean state){
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	g_object_set(G_OBJECT(instrument_track->priv->element), "realtime", state, NULL);
 }
 
 void jammo_instrument_track_set_live(JammoInstrumentTrack* instrument_track, gboolean state){
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	g_object_set(G_OBJECT(instrument_track->priv->element), "is-live", state, NULL);
 }
 
 GList * jammo_instrument_track_get_event_list(JammoInstrumentTrack* instrument_track) {
 	GList * eventlist;
+
+	g_return_val_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track), NULL);
+
 	g_object_get(G_OBJECT(instrument_track->priv->element),"eventlist", &eventlist, NULL);
 
 	return eventlist;
 }
 
 void jammo_instrument_track_set_event_list(JammoInstrumentTrack* instrument_track, GList* eventlist) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	if (instrument_track->priv->element==NULL) {
 		printf("Can't add eventlist to instrument-track, maybe track is not attached to sequencer (it must be before adding events)\n");
 		return;
@@ -351,6 +377,8 @@ void jammo_instrument_track_set_event_list(JammoInstrumentTrack* instrument_trac
 
 
 void jammo_instrument_track_set_volume(JammoInstrumentTrack* instrument_track, gfloat volume) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	if (volume>1.0) {
 		volume=1.0;
 	}
@@ -365,7 +393,11 @@ void jammo_instrument_track_set_volume(JammoInstrumentTrack* instrument_track, g
  Adds all midi events from given filename to given instrument_track.
 */
 void jammo_instrument_track_load_to_track_from_file (JammoInstrumentTrack* instrument_track, gchar *filename){
-        GList* list = jammomidi_file_to_glist(filename);
+        GList* list;
+
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+	
+	list = jammomidi_file_to_glist(filename);
         jammo_instrument_track_set_event_list(instrument_track, list);
 }
 
@@ -373,6 +405,8 @@ void jammo_instrument_track_load_to_track_from_file (JammoInstrumentTrack* instr
 	Clears event list of sampler. All recorded and added events are lost.
 **/
 void jammo_instrument_track_clear_events(JammoInstrumentTrack* instrument_track) {
+	g_return_if_fail(JAMMO_IS_INSTRUMENT_TRACK(instrument_track));
+
 	g_object_set(instrument_track->priv->element, "clear-events", TRUE, NULL);
 }
 
