@@ -63,6 +63,7 @@ static void destroy_element(JammoPlayingTrack* playing_track, GstElement** eleme
  * Return value: whether the track is muted or not
  */
 gboolean jammo_playing_track_get_muted(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), FALSE);
 
 	return playing_track->priv->muted;
 }
@@ -75,6 +76,8 @@ gboolean jammo_playing_track_get_muted(JammoPlayingTrack* playing_track) {
  * Sets whether the track is muted or audible.
  */
 void jammo_playing_track_set_muted(JammoPlayingTrack* playing_track, gboolean muted) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->muted != muted) {
 		playing_track->priv->muted = muted;
 		jammo_playing_track_set_volume_enabled(playing_track, playing_track->priv->muted || playing_track->priv->volume != 1.0);
@@ -94,6 +97,7 @@ void jammo_playing_track_set_muted(JammoPlayingTrack* playing_track, gboolean mu
  * Return value: a volume between 0.0 - 1.0
  */
 gfloat jammo_playing_track_get_volume(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), 0.0);
 	
 	return playing_track->priv->volume;
 }
@@ -106,6 +110,8 @@ gfloat jammo_playing_track_get_volume(JammoPlayingTrack* playing_track) {
  * Sets the individual volume of the track.
  */
 void jammo_playing_track_set_volume(JammoPlayingTrack* playing_track, gfloat volume) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->volume != volume) {
 		playing_track->priv->volume = volume;
 		jammo_playing_track_set_volume_enabled(playing_track, playing_track->priv->muted || playing_track->priv->volume != 1.0);
@@ -125,6 +131,7 @@ void jammo_playing_track_set_volume(JammoPlayingTrack* playing_track, gfloat vol
  * Return value: a volume between -1.0 - 1.0
  */
 gfloat jammo_playing_track_get_panning(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), 0.0);
 
 	return playing_track->priv->panning;
 }
@@ -137,6 +144,8 @@ gfloat jammo_playing_track_get_panning(JammoPlayingTrack* playing_track) {
  * Sets the audio position in stereo panorama (left, center, right).
  */
 void jammo_playing_track_set_panning(JammoPlayingTrack* playing_track, gfloat panning) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->panning != panning) {
 		playing_track->priv->panning = panning;
 		jammo_playing_track_set_panning_enabled(playing_track, playing_track->priv->panning != 0.0);
@@ -148,11 +157,14 @@ void jammo_playing_track_set_panning(JammoPlayingTrack* playing_track, gfloat pa
 }
 
 guint64 jammo_playing_track_get_echo_delay(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), 0);
 	
 	return playing_track->priv->echo_delay;
 }
 
 void jammo_playing_track_set_echo_delay(JammoPlayingTrack* playing_track, guint64 echo_delay) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->echo_delay != echo_delay) {
 		playing_track->priv->echo_delay = echo_delay;
 		if (playing_track->priv->audioecho) {
@@ -163,11 +175,14 @@ void jammo_playing_track_set_echo_delay(JammoPlayingTrack* playing_track, guint6
 }
 
 gfloat jammo_playing_track_get_echo_intensity(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), 0.0);
 
 	return playing_track->priv->echo_intensity;
 }
 
 void jammo_playing_track_set_echo_intensity(JammoPlayingTrack* playing_track, gfloat echo_intensity) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->echo_intensity != echo_intensity) {
 		playing_track->priv->echo_intensity = echo_intensity;
 		jammo_playing_track_set_echo_enabled(playing_track, playing_track->priv->echo_intensity != 0.0 && playing_track->priv->echo_feedback != 0.0);
@@ -179,11 +194,14 @@ void jammo_playing_track_set_echo_intensity(JammoPlayingTrack* playing_track, gf
 }
 
 gfloat jammo_playing_track_get_echo_feedback(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), 0.0);
 	
 	return playing_track->priv->echo_feedback;
 }
 
 void jammo_playing_track_set_echo_feedback(JammoPlayingTrack* playing_track, gfloat echo_feedback) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->echo_feedback != echo_feedback) {
 		playing_track->priv->echo_feedback = echo_feedback;
 		jammo_playing_track_set_echo_enabled(playing_track, playing_track->priv->echo_intensity != 0.0 && playing_track->priv->echo_feedback != 0.0);
@@ -195,11 +213,14 @@ void jammo_playing_track_set_echo_feedback(JammoPlayingTrack* playing_track, gfl
 }
 
 gboolean jammo_playing_track_get_volume_enabled(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), FALSE);
 
 	return playing_track->priv->volume_enabled;
 }
 
 void jammo_playing_track_set_volume_enabled(JammoPlayingTrack* playing_track, gboolean is_enabled) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->volume_enabled != is_enabled) {
 		playing_track->priv->volume_enabled = is_enabled;
 		if (!playing_track->priv->source || GST_STATE(playing_track->priv->source) != GST_STATE_PLAYING) {
@@ -215,11 +236,14 @@ void jammo_playing_track_set_volume_enabled(JammoPlayingTrack* playing_track, gb
 }
 
 gboolean jammo_playing_track_get_panning_enabled(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), FALSE);
 
 	return playing_track->priv->panning_enabled;
 }
 
 void jammo_playing_track_set_panning_enabled(JammoPlayingTrack* playing_track, gboolean is_enabled) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->panning_enabled != is_enabled) {
 		playing_track->priv->panning_enabled = is_enabled;
 		if (!playing_track->priv->source || GST_STATE(playing_track->priv->source) != GST_STATE_PLAYING) {
@@ -235,11 +259,14 @@ void jammo_playing_track_set_panning_enabled(JammoPlayingTrack* playing_track, g
 }
 
 gboolean jammo_playing_track_get_echo_enabled(JammoPlayingTrack* playing_track) {
+	g_return_val_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track), FALSE);
 
 	return playing_track->priv->echo_enabled;
 }
 
 void jammo_playing_track_set_echo_enabled(JammoPlayingTrack* playing_track, gboolean is_enabled) {
+	g_return_if_fail(JAMMO_IS_PLAYING_TRACK(playing_track));
+
 	if (playing_track->priv->echo_enabled != is_enabled) {
 		playing_track->priv->echo_enabled = is_enabled;
 		if (!playing_track->priv->source || GST_STATE(playing_track->priv->source) != GST_STATE_PLAYING) {
